/*  Robodoc Markup Header
*@***h* AMSU-A_FCDR_STAR/amsu.fcdr.gridded.AmsuFcdrGriddedDailyDataNadir.java
*
* NAME
*   amsu.fcdr.gridded.AmsuFcdrGriddedDailyDataNadir.java
*
* PURPOSE
*   Define AMSU-A daily gridded FCDR for nadir pixels only. Use it to buffer gridded FCDR first, then write to netcdf file.
* 
* DESCRIPTION
*	This class defines AMSU-A daily gridded FCDR for nadir pixels only.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   02/08/2016 Initial Version prepared for NCEI
*
*@***** 
 */
package amsu.fcdr.gridded;

import static amsu.fcdr.gridded.AmsuFcdrGridConstant.GRID_NUM_LAT;
import static amsu.fcdr.gridded.AmsuFcdrGridConstant.GRID_NUM_LON;
import static amsu.fcdr.gridded.AmsuFcdrL1cConstant.NUMBER_SELECTED_CHANNELS;

/**
*  Define AMSU-A daily gridded FCDR for nadir pixels only. Use it to buffer gridded FCDR first, then write to netcdf file.
* 
*   Xianjun Hao, George Mason University 
 */
public class AmsuFcdrGriddedDailyDataNadir {
    /**
     * Short name (ID) of satellite.
     */
    public String sat_name = null;
    
    /**
     * year.
     */
    public int year =0;
    
    /**
     * month
     */
    public int month = 0;
    
    /**
     * day
     */
    public int day = 0;
    
    /**
     * orbit flag, 0 for ascending, 1 for descending.
     */
    public byte orbit_flag = 0;
    
   /**
    * Gridded brightness temperature data for all channels (4-14).
    */
    public float[][][] fcdr_gridded_bt = null;

   /**
    *  Constructor. Allocate memory to create the array. Each field will  be accessed directly.
    */
    public  AmsuFcdrGriddedDailyDataNadir() {
        this.fcdr_gridded_bt = new float[GRID_NUM_LAT][GRID_NUM_LON][NUMBER_SELECTED_CHANNELS];
    }
    
}
