/*  Robodoc Markup Header
*@***h* AMSU-A_FCDR_STAR/amsu.fcdr.gridded.AmsuFcdrL1cConstant.java
*
* NAME
*   amsu.fcdr.gridded.AmsuFcdrL1cConstant.java
*
* PURPOSE
*   Define constants and conventions in processing AMSU-A level-1c FCDR data.
* 
* DESCRIPTION
*	This interface defines names of files and variables in processing AMSU-A level-1c FCDR data.
*
* AUTHOR
*   Xianjun Hao, George Mason University 
*
* COPYRIGHT 
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*
* REVISION HISTORY
*   12/08/2015 Initial Version prepared for NCEI
*
*@***** 
 */
package amsu.fcdr.gridded;

/**
 * This interface defines names of files and variables in processing AMSU-A
 * level-1c FCDR data.
 *
 * @author Xianjun Hao (xianjun.hao@noaa.gov)
 */
public interface AmsuFcdrL1cConstant {

    /**
     *  ID of FCDR data products based on IMICA method. 
     */    
    final public static int ID_FCDR_L1C_PRODUCT_IMICA = 0;

    /**
     *  ID of FCDR data products based on IMICA method with limb-correction. 
     */    
    final public static int ID_FCDR_L1C_PRODUCT_IMICA_LIMBCORR = 1;

    /**
     *  ID of FCDR data products based on OPR method. 
     */    
    final public static int ID_FCDR_L1C_PRODUCT_OPR = 2;

    /**
     *  ID of FCDR data products based on OPR method with limb-correction. 
     */    
    final public static int ID_FCDR_L1C_PRODUCT_OPR_LIMBCORR = 3;    
    
    /**
     * Variable name of sensor zenith angle in AMSU-A level-1c FCDR.
     */
    final public static String SENSOR_ZENITH_ANGLE = "sensor_zenith_angle";

    /**
     * Variable name of solar zenith angle in AMSU-A level-1c FCDR.
     */
    final public static String SOLAR_ZENITH_ANGLE = "solar_zenith_angle";

    /**
     * Variable name of latitude in AMSU-A level-1c FCDR.
     */
    final public static String LATITUDE = "latitude";

    /**
     * Variable name of longitude in AMSU-A level-1c FCDR.
     */
    final public static String LONGITUDE = "longitude";

    /**
     * Variable name of scan time in AMSU-A level-1c FCDR.
     */
    final public static String SCAN_TIME_SINCE78 = "scan_time_since78";

    /**
     *  Prefix for variable name of brightness temperatures in AMSU-A Level 1c file
     */
    final public static String PREFIX_FCDR_BRIGHTNESS_TEMPERATURE = "fcdr_brightness_temperature_";
    
    // FCDR - IMICA
    /**
     * Variable name of channel 4 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH4 = "fcdr_brightness_temperature_IMICA_ch4";

    /**
     * Variable name of channel 5 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH5 = "fcdr_brightness_temperature_IMICA_ch5";

    /**
     * Variable name of channel 6 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH6 = "fcdr_brightness_temperature_IMICA_ch6";

    /**
     * Variable name of channel 7 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH7 = "fcdr_brightness_temperature_IMICA_ch7";

    /**
     * Variable name of channel 8 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH8 = "fcdr_brightness_temperature_IMICA_ch8";

    /**
     * Variable name of channel 9 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH9 = "fcdr_brightness_temperature_IMICA_ch9";

    /**
     * Variable name of channel 10 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH10 = "fcdr_brightness_temperature_IMICA_ch10";

    /**
     * Variable name of channel 11 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH11 = "fcdr_brightness_temperature_IMICA_ch11";

    /**
     * Variable name of channel 12 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH12 = "fcdr_brightness_temperature_IMICA_ch12";

    /**
     * Variable name of channel 13 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH13 = "fcdr_brightness_temperature_IMICA_ch13";

    /**
     * Variable name of channel 14 IMICA brightness temperature in AMSU-A
     * level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH14 = "fcdr_brightness_temperature_IMICA_ch14";

    // FCDR - IMICA-Limcorrected
    /**
     * Variable name of channel 4 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH4 = "fcdr_brightness_temperature_IMICA_limbcorr_ch4";

    /**
     * Variable name of channel 5 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH5 = "fcdr_brightness_temperature_IMICA_limbcorr_ch5";

    /**
     * Variable name of channel 6 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH6 = "fcdr_brightness_temperature_IMICA_limbcorr_ch6";

    /**
     * Variable name of channel 7 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH7 = "fcdr_brightness_temperature_IMICA_limbcorr_ch7";

    /**
     * Variable name of channel 8 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH8 = "fcdr_brightness_temperature_IMICA_limbcorr_ch8";

    /**
     * Variable name of channel 9 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH9 = "fcdr_brightness_temperature_IMICA_limbcorr_ch9";

    /**
     * Variable name of channel 10 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH10 = "fcdr_brightness_temperature_IMICA_limbcorr_ch10";

    /**
     * Variable name of channel 11 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH11 = "fcdr_brightness_temperature_IMICA_limbcorr_ch11";

    /**
     * Variable name of channel 12 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH12 = "fcdr_brightness_temperature_IMICA_limbcorr_ch12";

    /**
     * Variable name of channel 13 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH13 = "fcdr_brightness_temperature_IMICA_limbcorr_ch13";

    /**
     * Variable name of channel 14 IMICA-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH14 = "fcdr_brightness_temperature_IMICA_limbcorr_ch14";

    // FCDR - OPR
    /**
     * Variable name of channel 4 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH4 = "fcdr_brightness_temperature_OPR_ch4";

    /**
     * Variable name of channel 5 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH5 = "fcdr_brightness_temperature_OPR_ch5";

    /**
     * Variable name of channel 6 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH6 = "fcdr_brightness_temperature_OPR_ch6";

    /**
     * Variable name of channel 7 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH7 = "fcdr_brightness_temperature_OPR_ch7";

    /**
     * Variable name of channel 8 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH8 = "fcdr_brightness_temperature_OPR_ch8";

    /**
     * Variable name of channel 9 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH9 = "fcdr_brightness_temperature_OPR_ch9";

    /**
     * Variable name of channel 10 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH10 = "fcdr_brightness_temperature_OPR_ch10";

    /**
     * Variable name of channel 11 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH11 = "fcdr_brightness_temperature_OPR_ch11";

    /**
     * Variable name of channel 12 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH12 = "fcdr_brightness_temperature_OPR_ch12";

    /**
     * Variable name of channel 13 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH13 = "fcdr_brightness_temperature_OPR_ch13";

    /**
     * Variable name of channel 14 OPR brightness temperature in AMSU-A level-1c
     * FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH14 = "fcdr_brightness_temperature_OPR_ch14";

    // FCDR - OPR-Limcorrected
    /**
     * Variable name of channel 4 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH4 = "fcdr_brightness_temperature_OPR_limbcorr_ch4";

    /**
     * Variable name of channel 5 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH5 = "fcdr_brightness_temperature_OPR_limbcorr_ch5";

    /**
     * Variable name of channel 6 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH6 = "fcdr_brightness_temperature_OPR_limbcorr_ch6";

    /**
     * Variable name of channel 7 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH7 = "fcdr_brightness_temperature_OPR_limbcorr_ch7";

    /**
     * Variable name of channel 8 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH8 = "fcdr_brightness_temperature_OPR_limbcorr_ch8";

    /**
     * Variable name of channel 9 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH9 = "fcdr_brightness_temperature_OPR_limbcorr_ch9";

    /**
     * Variable name of channel 10 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH10 = "fcdr_brightness_temperature_OPR_limbcorr_ch10";

    /**
     * Variable name of channel 11 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH11 = "fcdr_brightness_temperature_OPR_limbcorr_ch11";

    /**
     * Variable name of channel 12 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH12 = "fcdr_brightness_temperature_OPR_limbcorr_ch12";

    /**
     * Variable name of channel 13 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH13 = "fcdr_brightness_temperature_OPR_limbcorr_ch13";

    /**
     * Variable name of channel 14 OPR-limbcorrected brightness temperature in
     * AMSU-A level-1c FCDR.
     */
    final public static String FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH14 = "fcdr_brightness_temperature_OPR_limbcorr_ch14";

    
    /**
     *  Name of  scale_factor attribute for brightness temperature.
     */
    final public static String ATTRIBUTE_BRIGHTNESS_TEMPERATURE_SCALE_FACTOR = "scale_factor";
    
    /**
     *  Name of  valid range  attribute for brightness temperature.
     */
    final public static String ATTRIBUTE_BRIGHTNESS_TEMPERATURE_VALID_RANGE = "valid_range";
    
    
    /**
     * Variable name of quality flag for scans in AMSU-A level-1c FCDR.
     */
    final public static String QUALITY_FLAGS_SCAN_IMICA = "quality_flags_scan_IMICA";

    /**
     * Data quality flag for IMICA FCDR channel 4.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH4 = "quality_flags_pixel_IMICA_ch4";

    /**
     * Data quality flag for IMICA FCDR channel 5.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH5 = "quality_flags_pixel_IMICA_ch5";

    /**
     * Data quality flag for IMICA FCDR channel 6.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH6 = "quality_flags_pixel_IMICA_ch6";

    /**
     * Data quality flag for IMICA FCDR channel 7.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH7 = "quality_flags_pixel_IMICA_ch7";

    /**
     * Data quality flag for IMICA FCDR channel 8.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH8 = "quality_flags_pixel_IMICA_ch8";

    /**
     * Data quality flag for IMICA FCDR channel 9.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH9 = "quality_flags_pixel_IMICA_ch9";

    /**
     * Data quality flag for IMICA FCDR channel 10.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH10 = "quality_flags_pixel_IMICA_ch10";

    /**
     * Data quality flag for IMICA FCDR channel 11.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH11 = "quality_flags_pixel_IMICA_ch11";

    /**
     * Data quality flag for IMICA FCDR channel 12.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH12 = "quality_flags_pixel_IMICA_ch12";

    /**
     * Data quality flag for IMICA FCDR channel 13.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH13 = "quality_flags_pixel_IMICA_ch13";

    /**
     * Data quality flag for IMICA FCDR channel 14.
     */
    final public static String QUALITY_FLAGS_PIXEL_IMICA_CH14 = "quality_flags_pixel_IMICA_ch14";

    /**
     * Name of orbit flag, 0: ascending; 1: descending.
     */
    final public static String FCDR_ORBIT_ASCENDING_DESCENDING_FLAG = "fcdr_orbit_ascending_descending_flag";

    /**
     * Maximum latitude in AMSU-A level-1c FCDR.
     */
    final public static double MAXIMUM_LATITUDE = 90;

    /**
     * Minimum latitude in AMSU-A level-1c FCDR.
     */
    final public static double MINIMUM_LATITUDE = -90;

    /**
     * Maximum longitude in AMSU-A level-1c FCDR.
     */
    final public static double MAXIMUM_LONGITUDE = 180;

    /**
     * Minimum longitude in AMSU-A level-1c FCDR.
     */
    final public static double MINIMUM_LONGITUDE = -180;

    /**
     * Flag for ascending orbit.
     */
    final public static short ORBIT_ASCENDING = 0;

    /**
     * Flag for descending orbit.
     */
    final public static short ORBIT_DESCENDING = 1;

    /**
     * Flag for undefined orbit.
     */
    final public static short ORBIT_UNDEFINED = -1;

    /**
     * filled value for Bad geolocation
     */
    final public static float FILLED_BAD_GEOLOCATION = -999.0f;
    
    /**
     * valid minimum value of brightness temperature.
     */
    final public static float VALID_MINIMUM_BRIGHTNESS_TEMPERATURE = 150.0f;
    
    /**
     * Total scans per day
     */
    final public static int NUMBER_SCAN_PER_DAY = 10800;

    /**
     * Seconds per scan, around 8 seconds.
     */
    final public static double SECONDS_PER_SCAN = 8.0;

    /**
     * Pixel per Scan
     */
    final public static int NUMBER_PIXELS_PER_SCAN = 30;

    /**
     * Index for nadir pixel, left side (index start with 1).
     */
    final public static int INDEX_AMSU_A_NADIR_PIXEL_LEFT = 15;

    /**
     * Index for nadir pixel, right side (index start with 1).
     */
    final public static int INDEX_AMSU_A_NADIR_PIXEL_RIGHT = 16;
    
    /**
     * bit mask for bad scan lines
     */
    final public static byte BIT_MASK_BAD_SCAN = 1;

    /**
     * bit mask for bad geolocation
     */
    final public static byte BIT_MASK_BAD_GEOLOCATION = 2;

    /**
     * Number of selected channels
     */
    final public static int NUMBER_SELECTED_CHANNELS = 11;
    
    /**
     * Selected channels.
     */
    final public static int[] SELECTED_CHANNELS = {4, 5, 6,7,8,9,10,11,12,13,14};
    
    /**
     *  List of NOAA satellites used geocentric geolocation before July 6, 2006.
     */
    final public static String[] LIST_SATELLITE_GEOCENTRIC= {"N15", "N16", "N17", "N18" };
    
    /**
     * Get variable name of FCDR L1c data of a specified channel.
     * @param channel, channel number.
     * @param productId, ID of AMSU-A FCDR L1c data products, 0: IMICA, 1: IMICA with limb correction, 
     *                          2: OPR, 3: OPR with limb correction.
     * @return name of corresponding variable name of specified channel.
     */
     public static String getFcdrL1cVarName (int channel, int productId ) {
        String varName= null;
        switch (productId) {
            case AmsuFcdrL1cConstant.ID_FCDR_L1C_PRODUCT_IMICA: 
                switch(channel) {
                    case 4: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH4;
                        break;
                    case 5: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH5;
                        break;
                    case 6: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH6;
                        break;
                    case 7: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH7;
                        break;
                    case 8: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH8;
                        break;
                    case 9: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH9;
                        break;
                    case 10: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH10;
                        break;
                    case 11: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH11;
                        break;
                    case 12: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH12;
                        break;
                    case 13: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH13;
                        break;
                    case 14: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_CH14;
                        break;
                    default:
                        varName = null;
                        break;
                }
                break;
            case AmsuFcdrL1cConstant.ID_FCDR_L1C_PRODUCT_IMICA_LIMBCORR: 
                switch (channel) {
                    case 4: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH4;
                        break;
                    case 5: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH5;
                        break;
                    case 6: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH6;
                        break;
                    case 7: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH7;
                        break;
                    case 8: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH8;
                        break;
                    case 9: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH9;
                        break;
                    case 10: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH10;
                        break;
                    case 11: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH11;
                        break;
                    case 12: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH12;
                        break;
                    case 13: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH13;
                        break;
                    case 14: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_IMICA_LIMBCORR_CH14;
                        break;
                    default:
                        varName = null;
                        break;
                }    
                break;
            case AmsuFcdrL1cConstant.ID_FCDR_L1C_PRODUCT_OPR: 
                switch(channel) {
                    case 4: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH4;
                        break;
                    case 5: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH5;
                        break;
                    case 6: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH6;
                        break;
                    case 7: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH7;
                        break;
                    case 8: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH8;
                        break;
                    case 9: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH9;
                        break;
                    case 10: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH10;
                        break;
                    case 11: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH11;
                        break;
                    case 12: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH12;
                        break;
                    case 13: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH13;
                        break;
                    case 14: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_CH14;
                        break;
                    default:
                        varName = null;
                        break;
                }
                break;
            case AmsuFcdrL1cConstant.ID_FCDR_L1C_PRODUCT_OPR_LIMBCORR: 
                switch (channel) {
                    case 4: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH4;
                        break;
                    case 5: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH5;
                        break;
                    case 6: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH6;
                        break;
                    case 7: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH7;
                        break;
                    case 8: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH8;
                        break;
                    case 9: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH9;
                        break;
                    case 10: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH10;
                        break;
                    case 11: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH11;
                        break;
                    case 12: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH12;
                        break;
                    case 13: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH13;
                        break;
                    case 14: varName = AmsuFcdrL1cConstant.FCDR_BRIGHTNESS_TEMPERATURE_OPR_LIMBCORR_CH14;
                        break;
                    default:
                        varName = null;
                        break;
                }    
                break;               
            default: 
                varName = null;
                break;
        }        
        return varName;
    } 
    
     
     
     /**
     * Check if the geolocation data is geocentric. NOAA satellites used geocentric latitude before July 6, 2006. Starting 
     * from July 6, 2006, NOAA use geodetic latitude.
      * @param satId, ID of satellite.
      * @param year, year.
      * @param month, month.
      * @param day, day.
      * @return true if the geolocation data used geocentric coordinates, false otherwise.
      */
    public static boolean isLatitudeGeocentric(String satId, int year, int month, int day){
        boolean ret = false;
        long ptime = TimeUtility.getStartSecondSince78(year, month, day);        
        
        
        if (ptime >= AmsuFcdrGridConstant.STARTING_TIME_NOAA_GEODETIC_LATITUDE) {
            // all the related 6 satellites use geodetic since July 6, 2006.
            ret = false; 
        } else {
            // check if it's a NOAA satellite
            int num = AmsuFcdrL1cConstant.LIST_SATELLITE_GEOCENTRIC.length;
            for(int k=0; k<num; k++) {
                if (satId.equalsIgnoreCase(AmsuFcdrL1cConstant.LIST_SATELLITE_GEOCENTRIC[k])){
                    ret = true;
                    break;
                }
            }    
        }
         
        return ret;
     }
     
}
