#@***h* AMSU-A_FCDR_STAR/archive_fcdr_grid.sh
# NAME
#   archive_fcdr_grid.sh
# 
# PURPOSE
#   To 
# 
# DESCRIPTION
#   This script archive AMSU-A gridded FCDR files by month, and generate MD5 checksum.   
#
# AUTHOR
#   Xianjun Hao, George Mason University
# 
# CREATION DATE
#   06/06/2016
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#   ALTHOUGH UNRESTRICTED, THE USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE AND
#   CITE THE NESDIS/CENTER FOR SATELLITE APPLICATIONS AND RESEARCH MSU/AMSU REPROCESSING
#   TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, AND/OR ANY DERIVED DATA PRODUCTS THAT WERE
#   PRODUCED USING THE ORIGINAL DATA SET. 
#   A PROPERLY ACKNOWLEDGEMENT SHOULD USE THE FOLLOWING WORDING 'THE SOFTWARE AND DATASETS
#   WERE DEVELOPED AND PROVIDED BY THE NOAA MSU/AMSU REPROCESSING TEAM' AND THE 
#   FOLLOWING REFERENCES SHOULD BE CITED WHEN USING THE SOFTWARE AND DATASETS  
#   Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of AMSU-A observations for weather and
#   climate applications, J. Geophys. Res., Vol. 116, D23113, doi:10.1029/2011JD016205
#   Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and D. Tarpley (2006)
#   Recalibration of microwave sounding unit for climate studies using simultaneous nadir 
#   overpasses. J. Geophys. Res., 111, D19114, doi:10.1029/2005JD006798
#   Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of AMSU-A 
#   observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# 
#@*****/

cdate="C"`date +%Y%m%d`
prefix="NESDIS-STAR_FCDR-GRID_AMSU-A_V01R00"
dirin=/home/xhao/data/AMSU/product/netcdf4
dirout=/home/xhao/data/AMSU/product/delivery

echo ${cdate}

for satname in N15 N16 N17 N18 AQUA M02 
do
platform=$satname
for year in  2016 2015 2014 2013 2012 2011 2010 2009 2008 2007 2006 2005 2004 2003 2002 2001 2000 1999 1998
do
  subdir=$satname/$year
  dirSrc=$dirin/$subdir
  dirDst=$dirout

  if [ -d $dirSrc ]; then
     if [ ! -e $dirDst ]; then
         mkdir -p $dirDst
     fi 
     ##echo $dirDst
     cd $dirSrc
     
     for ((imon=1;imon<=12;imon++))
     do 
          mm=`printf "%0*d\n" 2 $imon`
          bb=`ls -l $prefix*D$year$mm*.nc 2>/dev/null | wc -l `
          if [ $bb -gt 0 ]; then
              ##echo $satname$imon$bb
              tarfn=${prefix}_${platform}_D${year}${mm}_${cdate}.tar
              tar -cvf $tarfn $prefix*D${year}${mm}*.nc
              mnfname=$tarfn.mnf
              md5=`md5sum $tarfn | awk '{print $1}'`
              size=`du -b $tarfn | awk '{print $1}'`
              echo "${tarfn},${md5},${size}" > $mnfname
              mv $tarfn $dirDst/
              mv $mnfname $dirDst/    
          fi 
     done             

  fi



done
done

