#@***h* AMSU-A_FCDR_STAR/nc3_to_nc4.sh
# NAME
#   nc3_to_nc4.sh 
# 
# PURPOSE
#   To convet AMSU-A daily gridded FCDR files from netCDF-3 to netCDF-4 format
# 
# DESCRIPTION
#   This script converts AMSU-A daily gridded FCDR files from netCDF-3 to netCDF-4 format
#   for all satellites. It calls the nccopy utitlity to convert netCDF-3 format FCDR files generated by the Java 
#   progrm to netCDF-4 files, with compression.
#
# AUTHOR
#   Xianjun Hao, George Mason University
# 
# CREATION DATE
#   06/06/2016
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#   ALTHOUGH UNRESTRICTED, THE USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE AND
#   CITE THE NESDIS/CENTER FOR SATELLITE APPLICATIONS AND RESEARCH MSU/AMSU REPROCESSING
#   TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, AND/OR ANY DERIVED DATA PRODUCTS THAT WERE
#   PRODUCED USING THE ORIGINAL DATA SET. 
#   A PROPERLY ACKNOWLEDGEMENT SHOULD USE THE FOLLOWING WORDING 'THE SOFTWARE AND DATASETS
#   WERE DEVELOPED AND PROVIDED BY THE NOAA MSU/AMSU REPROCESSING TEAM' AND THE 
#   FOLLOWING REFERENCES SHOULD BE CITED WHEN USING THE SOFTWARE AND DATASETS  
#   Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of AMSU-A observations for weather and
#   climate applications, J. Geophys. Res., Vol. 116, D23113, doi:10.1029/2011JD016205
#   Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and D. Tarpley (2006)
#   Recalibration of microwave sounding unit for climate studies using simultaneous nadir 
#   overpasses. J. Geophys. Res., 111, D19114, doi:10.1029/2005JD006798
#   Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of AMSU-A 
#   observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# 
#@*****/


dirSrc0=/home/xhao/data/AMSU/FCDR_Gridded/L3/
dirDst0=/home/xhao/data/AMSU/FCDR_Gridded/netcdf4/

#pathname for nccopy, which convert netCDF-3 to netCDF-4
nccopy=/opt/netcdf4/bin/nccopy


for satname in N15 N16 N17 N18 AQUA M02 
do
for year in  2016 2015 2014 2013 2012 2011 2010 2009 2008 2007 2006 2005 2004 2003 2002 2001 2000 1999 1998
do
  subdir=$satname/$year/
  dirDst=$dirDst0$subdir
  dirSrc=$dirSrc0$subdir

  if [ -d $dirSrc ]; then
      mkdir -p $dirDst
      echo $dirDst
      cd $dirSrc

      for file in *.nc
      do
          pathDst=$dirDst$file        
          $nccopy -k 4  -d 6 $file $pathDst
      done
  fi



done
done
