/*@***h* AMSU-A_FCDR_STAR/amsu.amsua.AMSUA.java
* NAME
*   amsu.amsua.AMSUA.java 
* 
* PURPOSE
*   To define AMSU-A related constants.
* 
* DESCRIPTION
*   This class provides definitions of AMSU-A instrument characteristics related 
*   constants. 
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   12/01/2008
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial version prepared for NCDC.
*   04/21/2011 Moved calibration method related constants to a separate interface
*                (CalibrationInterface)
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry. 
* 
*
*@*****/
 
package amsu.amsua;

import pub.CalibrationInterface;

public interface AMSUA extends CalibrationInterface {
    
    static public final int NUM_CHANNELS=15;       //number of channels

    static public final int NUM_MILISECONDS_PER_SCANLINE=8000;  //unit millisecond time spend on each scan line
    static public final int NUM_SCANLINE_MAX=1600; //maxium number of scan lines per level 1b file
    static public final int NUM_SPOTS_PER_LINE=30; //number of observations per scan line
 
    static public final int NUM_PRTS_A1=46; //ALL PRTs for A1  number of PRTs for A1
    static public final int NUM_PRTS_A2=20; //number of PRTs for A2
    static public final int NUM_WT_PRTS_A1=5;  //number of warm target PRTs for A1
    static public final int NUM_WT_PRTS_A2=7; // number of warm target PRTs for A2
    static public final int NUM_SUB_INSTRUMENTS=3; //A1-1,A1-2,A2
    static public final String[] wtInstruments = {"A1-1", "A1-2", "A2"};
  
    static public final int L1B_RECORD_LEN_MAX=2560; //records length for NOAA AMSU-A level 1b file/    
 
    //for TLT only
    static public final int CHANNEL_FOR_CALCULATING_TLT=4;
    //MSU channels that match AMSU-A channels  -- for MSU/AMSU-A merging
    static public final int[] AMSUAChannel2MSUChannel={-1,-1,0,-1,1,
            -1,2,-1,3,-1,    -1,-1,0,-1,-1};
    
    //source: Mo 1999 AMSU-A Antenna Pattern Correction
    public static final float[] nedtsN15Specified={0.3f,0.3f,0.4f,0.25f,0.25f, 0.25f,0.25f,0.25f,0.35f,0.40f, 0.40f,0.60f,0.80f,1.20f, 0.50f};
    public static final float[] nedtsN15={0.211f,0.265f,0.219f,0.143f,0.148f, 0.154f,0.132f,0.141f,0.236f,0.250f, 0.280f,0.400f,0.539f,0.914f, 0.116f};
}
