/*@***h* AMSU-A_FCDR_STAR/amsu.amsua.AMSUAQualityControl.java
* NAME
*   amsu.amsua.AMSUAQualityControl.java 
* 
* PURPOSE
*   To provide AMSU-A scene temperature and warm target temperature quality control.
* 
* DESCRIPTION
*   This class defines threshold values for valid AMSU-A scene and warm target 
*   temperatures. It also provide methods for verify AMSU-A scene and warm target
*   temperatures.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   12/01/2009
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial version prepared for NCDC
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry. 
*
*@*****/
 
 
package amsu.amsua;


public class AMSUAQualityControl {
    public static final float missing_value=-9999;
    public static final float TEMPERATURE_MAX=400;
    public static final float TEMPERATURE_MIN=100;
    public static final float TEMPERATURE_MAX_WT=350;
    public static final float TEMPERATURE_MIN_WT=200;
 
    public static final float[] minTs={0,0,0,180,190,195,190,185,175,175,175,180,185,190,0};
    public static final float[] maxTs={0,0,0,295,275,255,250,245,245,245,255,265,280,295,0};

   //LEVEL 3 
    public static final float[] TEMPERATURE_MAX_L3_AMSUA={350,350,350,300,300,300,300,300,300,300,300,300,300,300,350};
    public static final float[] TEMPERATURE_MIN_L3_AMSUA={100,100,100,170,170,170,170,170,170,170,170,170,170,170,100};
    static public int checkTemperatureL3(int channel, float temp){
        if (pub.QualityControl.isMissingValue(temp)){
            return -2;
        }else if (temp<TEMPERATURE_MIN_L3_AMSUA[channel]){
            return -1;
        }else if (temp>TEMPERATURE_MAX_L3_AMSUA[channel]){
            return 1;
        }else
            return 0; //within range
    }

    static public boolean isValidTemperature(float temp){
        return temp>TEMPERATURE_MIN && temp<TEMPERATURE_MAX;
    }
    static public boolean isValidWarmTargetTemperature(float temp){
        return temp>TEMPERATURE_MIN_WT && temp<TEMPERATURE_MAX_WT;
    }

    
}
