/*@***h* AMSU-A_FCDR_STAR/amsu.amsua.L1B.header.AMSUAInstrumentStatus.java
* NAME
*   amsu.amsua.L1B.header.AMSUAInstrumentStatus.java 
* 
* PURPOSE
*   To parse AMSU-A instrument status for A1 and A2.
* 
* DESCRIPTION
*   This class provide methods for parsing instrument status for antenna systems 
*   A1 and A2
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   10/07/2010
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*
*@*****/
 
 
package amsu.amsua.L1B.header;
import util.*;

public class AMSUAInstrumentStatus {
    byte coldCalPosition;
    byte antennaInNadirPosition,antennaInColdCalPosition,antennaInWarmCalPosition;
    byte fullScanMode;
    byte survivalHeater;
    byte modulePower;
    byte compensatorMotor;  //A2 only
    byte[] scannerPower=new byte[3]; //for A1-1,A1-2,A2
    byte phaseLockLoop; //for A1 only
    
    /**
     * Parse A1 instrument status 
     * @param buffer - buffer for the L1B header record 
     */
    public void parseA1(byte[] buffer){
        int offset=132;
        int temp4;
        temp4=ParserUtil.combineInteger4(buffer[offset],buffer[offset+1],buffer[2],buffer[3]);
        int debug=0;
        
        coldCalPosition=(byte)((temp4>>13)&0x3);        
        antennaInNadirPosition=(byte)((temp4>>12)&0x1);
        antennaInColdCalPosition=(byte)((temp4>>11)&0x1);
        antennaInWarmCalPosition=(byte)((temp4>>10)&0x1);
        if (antennaInColdCalPosition!=0 ||  antennaInWarmCalPosition!=0){
            debug=1;
        }
        fullScanMode=(byte)((temp4>>9)&0x1);
        modulePower=(byte)((temp4>>5)&0x1);
        survivalHeater=(byte)((temp4>>4)&0x1);
        phaseLockLoop=(byte)((temp4>>3)&0x1); //for A1 only
        if (phaseLockLoop==1)
            debug=1;
        else
            debug=0;
        scannerPower[1]=(byte)((temp4>>2)&0x1);
        scannerPower[0]=(byte)((temp4)&0x1);
       
    }

    /**
     * Parse A2 instrument status
     * @param buffer - buffer of L1B header record
     */
    public void parseA2(byte[] buffer){
        int offset=120;
        int temp4;
        temp4=ParserUtil.combineInteger4(buffer[offset],buffer[offset+1],buffer[2],buffer[3]);
     
        coldCalPosition=(byte)((temp4>>13)&0x3);        
        antennaInNadirPosition=(byte)((temp4>>12)&0x1);
        antennaInColdCalPosition=(byte)((temp4>>11)&0x1);
        antennaInWarmCalPosition=(byte)((temp4>>10)&0x1);
        fullScanMode=(byte)((temp4>>9)&0x1);
        survivalHeater=(byte)((temp4>>4)&0x1);
        modulePower=(byte)((temp4>>3)&0x1);
        compensatorMotor=(byte)((temp4>>2)&0x1);  
        survivalHeater=(byte)((temp4>>1)&0x1);
    }
    
}

