/*@***h* AMSU-A_FCDR_STAR/amsu.amsua.L1B.noaa.AMSUAAnalogTelemetryConversion.java
* NAME
*   amsu.amsua.L1B.noaa.AMSUAAnalogTelemetryConversion.java 
* 
* PURPOSE
*   To support AMSU-A Analog Telemetry Conversion Coefficients.
* 
* DESCRIPTION
*   This class provides methods to parse and access AMSU-A level 1b analog 
*   telemetry data. It was used for channel 6 frequency shift exploration.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   09/14/2011
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package amsu.amsua.L1B.noaa;

import util.*;
public class AMSUAAnalogTelemetryConversion {
    static public boolean bParse=false;  //control whether to parse this section of data 
    
    static int NUM_AnalogHouseKeepingData=28;
    //header offset 1700 - 1920
    //index 20-22 is GDO Voltage 54.4 GHz ch 5/6/7 intercept and slope
    float[][] coeffsA1=new float[NUM_AnalogHouseKeepingData][2]; //0-intercept 1-slope
    
    //not used at this time
    float[][] coeffsA2; 

    /**
     * parse conversion coefficients from level 1c header
     * @param buffer - buffer of header record 
     * 
     * */
    public void parseHeader(byte[] buffer){
        if (!bParse){
            return;
        }
        int temp4;      
        int offset=1700;       
        short temp2;
        float f2;
        
        //A1 Analog telemetry conversion
        offset=1700;
        for (int i=0;i<NUM_AnalogHouseKeepingData;i++){
            for (int j=0;j<2;j++){//0 - intercept 1 - slope
                temp4=(int)(ParserUtil.combineInteger4(buffer[offset],buffer[offset+1],buffer[offset+2],buffer[offset+3]));
                f2=temp4*0.001f;
                coeffsA1[i][j]=f2;  //min,norminal,max
                offset+=4;
            }
        }

        //A2 Analog telemetry conversion missing
    }
    
    
    /**
     * Parse one scan line of analog telemetry data
     * @param buffer - buffer of level 1b scan line 
     * @param results - analog telemetry data
     */
    public void parseLine(byte[] buffer,float[] results){
        if (!bParse){
            return;
        }
        
          
        int offset;       
        short temp2;
       
        byte b;
        //A1 Analog telemetry conversion
        offset=2152;
        for (int i=0;i<NUM_AnalogHouseKeepingData;i++){
                b=buffer[offset];
                temp2=(short) (0x00ff & b);

                results[i]=0.02f*(coeffsA1[i][0]+coeffsA1[i][1]*temp2); //0.02 is based on header records
                offset++;
        }
        
        System.out.println(" word8="+results[8]+" word12="+results[12]+" ch3="+results[18]+" ch4="+results[19]+" ch5="+results[20]+ " ch6="+results[21]+" ch7="+results[22]+" ch8="+results[23]+
                " PPLOPrimary="+results[24]);
    }
}
