/*@***h* AMSU-A_FCDR_STAR/amsu.amsua.L1C.AMSUAL1CCalibrator.java
* NAME
*   amsu.amsua.L1C.AMSUAL1CCalibrator.java 
* 
* PURPOSE
*   To convert scene raw counts to the IMICA recalibrated or 
*   NOAA pre-launch calibrated radiances.
* 
* DESCRIPTION
*   This class provides methods for one or multiple scanline(s)'s  
*   raw counts to NOAA pre-launch calibrated radiance or the IMICA recalibrated
*   radiances (through super class). 
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   12/03/2008
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   04/03/2009 Created L1CCalibrator and moved member method to it to support 
*              to support code reuse in the future.
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry.
*
*@*****/
 
 
package amsu.amsua.L1C;

import pub.L1C.*;


public class AMSUAL1CCalibrator extends L1CCalibrator{

    /** 
     * @param countsScene           - input, multi-scanline line, 15-channel, 30-spots of scene raw counts
     * @param coeffsOperational     - input, NOAA pre-launch calibration coefficients
     * @param radiances             - output radiances
     */ 
    public static void count2RadianceOperational(float[][][] countsScene,double[][][] coeffsOperational,float[][][] radiances){
        int idxLine;
        int nScans=countsScene.length;
        for (idxLine = 0; idxLine < nScans; idxLine++) {
            count2RadianceOperational(countsScene[idxLine], coeffsOperational[idxLine],          
                radiances[idxLine]);            
       }
    }

   /** 
     * @param countsScene           - input, 15-channel, 30-spots of scene raw counts
     * @param coeffsOperational     - input, NOAA pre-launch calibration coefficients
     * @param radiances             - output radiances
     */ 
    public static void count2RadianceOperational(float[][] countsScene,double[][] coeffsOperational,float[][] radiances){
        int i, j;
        double f0, f1, f2, temp;
        float count;
        int nChannels = countsScene.length;
        int nSpots = countsScene[0].length;
        for (i = 0; i < nChannels; i++) {
            f2 = coeffsOperational[i][0];
            f1 = coeffsOperational[i][1];
            f0 = coeffsOperational[i][2];

            for (j = 0; j < nSpots; j++) {
                count = countsScene[i][j];
                temp = f0 + f1 * count + f2 * count * count;
                radiances[i][j] = (float) temp;
            }
        }
    }

    
}
