/*@***h* AMSU-A_FCDR_STAR/grid.Grid.java
* NAME
*   grid.Grid.java 
* 
* PURPOSE
*   To support gridded data.
* 
* DESCRIPTION
*   This class defines constants and grid mapping method used by MSU/AMSU-A/SSU 
*   TCDRs, and gridded ancillary data, such as LandType.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*    05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package grid;

public class Grid {
   static public final float RESOLUTION_LAT=2.5F;
   static public final float RESOLUTION_LON=2.5F;  
   static public final int GRID_Y_MAX=(int)(180/RESOLUTION_LON);
   static public final int GRID_X_MAX=(int)(360/RESOLUTION_LON);
   
   public static void getGrid(float xxlat, float xxlon, short[] xy){

          float xlat, xlon;
          short x,y;
   
          
          xlat = 90.0f + xxlat;
          xlon = xxlon + 180.0f;

          y= (short)(xlat/RESOLUTION_LAT);
          
          if (y >= GRID_Y_MAX) 
             y = GRID_Y_MAX-1;

          x=(short)(xlon/RESOLUTION_LON);
          if (x >= GRID_X_MAX) 
              x = GRID_X_MAX-1; 
          
          xy[0]=x;
          xy[1]=y;
     }
 
}
