/*@***h* AMSU-A_FCDR_STAR/io.File.java
* NAME
*   io.File.java 
* 
* PURPOSE
*   To provide file utilities.
* 
* DESCRIPTION
*   This class provide convenient methods for directory/filename operations.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*    05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package io;

import java.io.*;

public class File {
    protected String dir;
    protected String name;
    protected String pathname;
    
    public File(){
        
    }
    
    public String getName(){
        return name;
    }
    
    public String getDirectory(){
        return dir;
    }
    
    /**
     * Should be overridden by subclasses
     * @param pathname - pathname
     * @return 0
     */
    public int open(String pathname){
        return 0;
    }
    public void setFilename(String dir,String name){
        this.dir=dir;
        this.name=name;
        pathname=dir+"/"+name;
    }
    public void setFilename(String path){
        dir=getDirectory(path); 
        name=getFilename(path);
        pathname=dir+"/"+name;
    }
     
    static public String getDirectory(String fullpath){
      byte[] str=fullpath.getBytes();
        int i;
        String dir;
        
        i=fullpath.length()-1; 
        while (i>=0 && str[i]!='/' && str[i]!='\\') 
            i--;
 
        dir=fullpath.substring(0, i+1);
        return dir;       
    }
    
    static public String getFilename(String fullpath){
        byte[] str=fullpath.getBytes();
        int i,ii;
        String name;
        
        i=fullpath.length()-1; 
        while (i>=0 && str[i]!='/' && str[i]!='\\') 
            i--;
        ii=fullpath.length()-1;
        while (!Character.isLetter(str[ii]))
		 ii--;
        
        while (str[i]=='/' || str[i]=='\\')
		 i++;
        name=fullpath.substring(i, ii+1);
        return name;
    }  

    static public String[] readInputFiles(String filelist){
        String[] files=null;
        String line=null;
        int n=0;
        RandomAccessFile fp;
        
        try {
            fp = new RandomAccessFile(filelist, "r");

            //count number of files
            while (true) {
                line = fp.readLine();
                if (line != null) {
                    n++;
                } else {
                    break;
                }
            }

            //actually read file names
            files = new String[n];

            fp.seek(0);
            for (int i = 0; i < n; i++) {
                files[i] = fp.readLine();
            }

            fp.close();
        } catch (FileNotFoundException ex) {
            ex.printStackTrace();
            System.out.println("file="+filelist+" not exist!!!");
            System.exit(-1);
        } catch (IOException ex) {
            ex.printStackTrace();
            System.out.println("IO Exception when the system reads "+filelist+"!!!");
            System.exit(-1);
        }
       
        return files;
    }
 
    static public void deleteFile(String pathname){
        java.io.File file = new java.io.File(pathname);
        if (file.exists() && file.isFile()) {
            file.delete();   
        }
    }
}
