/*@***h* AMSU-A_FCDR_STAR/io.FileLog.java
* NAME
*   io.FileLog.java 
* 
* PURPOSE
*   To support log file for CDR data processing.
* 
* DESCRIPTION
*   This class defines constant, variables, and methods that support logging.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package io;


public class FileLog extends FileRandom{
    public static final int NEW=0;
    public static final int APPEND=1;
    
    public static final int PRIORITY_MUST_WRITE_MSG=1;
    public static final int PRIORITY_FATAL_ERROR=2;
    public static final int PRIORITY_ERROR=4;
    public static final int PRIORITY_WARNING=8;
    public static final int PRIORITY_OPTINAL_MSG=16;
    public static final int PRIORITY_DEBUG=32;

    int priority=PRIORITY_MUST_WRITE_MSG|PRIORITY_FATAL_ERROR|
            PRIORITY_ERROR|PRIORITY_WARNING;

    
    @Override
    public synchronized int open(String pathname){
        //open file and move to the end of the file
        int status=super.open(pathname,"rw");
        if (status!=0)
            return -1;
        long len=length();
        seek(len);
        if (len<1)
            return NEW;
        else
            return APPEND;

    }
    public void setPriority(int p){
        priority=p;
    }
    
    public synchronized void writeLog(String str,int priorityCur){
        if ((priorityCur & priority) !=0){            
            System.out.println(str);
            super.writeString(str+"\r\n");
        }
    }

    public synchronized void writeLog(String str,int priorityCur,boolean bPrint2Screen){
        if ((priorityCur & priority) !=0){     
            if (bPrint2Screen)
                System.out.println(str);
            super.writeString(str+"\r\n");
        }
    }
    
    public synchronized void writeLog(String[] strs, int priorityCur) {
        if (strs == null) {
            return;
        }
        if ((priorityCur & priority) !=0){        
            int n = strs.length;
            for (int i = 0; i < n; i++) {
                super.writeString(strs[i] + "\r\n");
            }
        }
    }
}
