/*@***h* AMSU-A_FCDR_STAR/io.FileRandom.java
* NAME
*   io.FileRandom.java 
* 
* PURPOSE
*   To support random access file.
* 
* DESCRIPTION
*   This class provides convenient methods for random access file.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package io;

import java.io.*;
import pub.QualityControl;
import util.*;


public class FileRandom extends io.File {
    RandomAccessFile fp;
    public FileRandom() {
    }

   
    public int open(String pathname,String mode){
        super.setFilename(pathname);
        try{
            if (mode.equalsIgnoreCase("w"))
                mode="rw";
            fp=new RandomAccessFile(new java.io.File(pathname),mode);                                        
        }catch (IOException e){
            String str="File "+pathname+"Open failed; mode="+mode;
            System.out.println(str);
            e.printStackTrace();
            return -1;
        }
        return 0;
    }
    
    public void close(){
        if (fp!=null){
         try{
             fp.close();
        }catch (IOException e){
            String str="Input File "+pathname+"close failed";
            System.out.println(str);
        }
        
            fp=null;
        }
    }
    
    public int writeString(String str){  
        try{
            fp.writeBytes(str);
   
        }catch (IOException e){
            
        }
        return 0;
    }
    
    public int writeShort(short value){
       int b1,b2;
       b1=(value&0x0ff00)>>8;
       b2=value&0x0ff;
       try{
            fp.writeByte(b1);
            fp.writeByte(b2);
   
        }catch (IOException e){
            
        }
        return 0;
        
    }
    
    public int writeInt(int value){
          try{
            fp.writeInt(value);
   
        }catch (IOException e){
            
        }
        return 0;    
    }
    
    public int writeBytes(byte[] bytes){
         try{
            fp.write(bytes,0,bytes.length);
   
        }catch (IOException e){
            
        }
        return 0;            
    }
    public int writeFloat(float v){
         try{
            fp.writeFloat(v);
   
        }catch (IOException e){
            
        }
        return 0;            
    }
    
    public static int putFloatFORTRAN(float value, byte[] buf,int offset){
        int intValue=Float.floatToIntBits(value);
        buf[offset]=(byte)(intValue & 0xff);
        buf[offset+1]=(byte)((intValue>>8)& 0xff);        
        buf[offset+2]=(byte)((intValue>>16)& 0xff);
        buf[offset+3]=(byte)((intValue>>24) & 0xff);        
        return 4;
    }
    
    public int writeFloatsFORTRAN(float[][] values2D,byte[] buffer){
        int n1=values2D.length;
        int n2=values2D[0].length;
        int index=0;
        for (int i=0;i<n1;i++){
            for (int j=0;j<n2;j++){
                index+=putFloatFORTRAN(values2D[i][j], buffer, index);
            }
        }
        writeBytes(buffer);
        return 0;
    }

 
    public int writeFloatsFORTRAN(float[] values,byte[] buffer){
        int n=values.length;
        int index=0;
        for (int i=0;i<n;i++){
            index+=putFloatFORTRAN(values[i], buffer, index);
        }
        writeBytes(buffer);
        return 0;
    }
/*
    public int writeFloats(float[] values,byte[] buffer){
        int n=values.length;
        int index=0;
        for (int i=0;i<n;i++){
            index+=NOAADataSetPub.putFloat(values[i], buffer, index);
        }
        writeBytes(buffer);
        return 0;
    }
*/
     public int read(byte[] bytes){
         int status=0;
         int n;
         try{
            n=fp.read(bytes);
            if (n<=0)
                status=-1;
   
        }catch (IOException e){
            
        }
        return status;            
    }
    public int readInt(){
         int status=0;
         int n;
         try{
            n=fp.readInt();
            return n;
   
        }catch (IOException e){
            
        }
        return QualityControl.missing_value_short;            
    }

    public int read(byte[] bytes,int nBytes){
         int status=0;
         int n;
         try{
            n=fp.read(bytes,0,nBytes);
            if (n<=0)
                status=-1;
   
        }catch (IOException e){
            
        }
        return status;            
    }

      
    public int writeBytes(byte[] bytes,int start,int len){
         try{
            fp.write(bytes,start,len);
   
        }catch (IOException e){
            
        }
        return 0;            
    }

    public int seek(long pos){
        int status=0;
        try{
            fp.seek(pos);   
        }catch (IOException e){
            status=-1;
        }
        return status;             
    }
    public long length(){
        long length;
         try{
            length=fp.length();
        }catch (IOException e){
            length=-1;
        }
       return length;
    }
    public static void writeStrings(String pathout,String[] strs){
        FileRandom fp=new FileRandom();        
        fp.open(pathout,"w");
        
        if (strs!=null){
            int n = strs.length;
            System.out.println("file="+pathout+" nstrings="+n);
            for (int i = 0; i < n; i++) {
                fp.writeString(strs[i] + "\n");
            }
        }else{
            System.out.println("Empty String Array file="+pathout);
        }
        fp.close();
    }

    public int read(float[] values,int n){       
        byte[] bytes=new byte[n*4];
        int n1;
        long temp;
        int ret=1;
        
        try{
           n1=fp.read(bytes);
           int offset=0;
           int i=0;
           while (offset<n1 && offset+3<n1){
               values[i]=ParserUtil.combineFloat(bytes[offset],bytes[offset+1],
                       bytes[offset+2],bytes[offset+3]);
                ret=0;
                offset+=4;
                i++;
           }              
           if (n1<values.length*4){
               temp=fp.getFilePointer();
               ret=1;
           }
        }catch (IOException e){
            System.out.println("InputFile::read failed");
            return -1;
        }
        return ret;
    }

}
