/*@***h* AMSU-A_FCDR_STAR/io.netcdf.NetcdfFileWriteableAttributeUtil.java
* NAME
*    io.netcdf.NetcdfFileWriteableAttributeUtil.java 
* 
* PURPOSE
*   To support variable attributes of netcdf file.
* 
* DESCRIPTION
*   This class provides constants and methods for different variable attributes.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 


package io.netcdf;

import ucar.nc2.NetcdfFileWriteable;


public class NetcdfFileWriteableAttributeUtil{
                    
    static public final String ATTR_LONGNAME="Long_Name";
    static public final String ATTR_DATARANGE="Data_Range";
    static public final String ATTR_FILLINGVALUE="Filling_Value";
    static public final String ATTR_UNIT="UNIT";
    static public final String ATTR_SCALINGFACTOR="Scaling_Factor";

    static public void addVariableAttributes(NetcdfFileWriteable ncfile,String varName,String strLongName,String strDataRange,String strFillingValue){
            ncfile.addVariableAttribute(varName,ATTR_LONGNAME,strLongName);
            ncfile.addVariableAttribute(varName,ATTR_DATARANGE,strDataRange);
            ncfile.addVariableAttribute(varName,ATTR_FILLINGVALUE,strFillingValue);        
    }
    static public void addVariableAttributes(NetcdfFileWriteable ncfile,String varName,String strLongName,String strDataRange,
            String strFillingValue,String strUnit){
            ncfile.addVariableAttribute(varName,ATTR_LONGNAME,strLongName);
            ncfile.addVariableAttribute(varName,ATTR_UNIT,strUnit);        
            ncfile.addVariableAttribute(varName,ATTR_DATARANGE,strDataRange);
            ncfile.addVariableAttribute(varName,ATTR_FILLINGVALUE,strFillingValue);        
    }
    static public void addVariableAttributes(NetcdfFileWriteable ncfile,String varName,String strLongName,String strDataRange,
            String strFillingValue,String strUnit,String strScaling){
            ncfile.addVariableAttribute(varName,ATTR_LONGNAME,strLongName);
            ncfile.addVariableAttribute(varName,ATTR_UNIT,strUnit);        
            ncfile.addVariableAttribute(varName,ATTR_DATARANGE,strDataRange);
            ncfile.addVariableAttribute(varName,ATTR_FILLINGVALUE,strFillingValue);        
            ncfile.addVariableAttribute(varName,ATTR_SCALINGFACTOR,strScaling);        
    }
    

}
