/*@***h* AMSU-A_FCDR_STAR/io.netcdf.netCDFUtil.java
* NAME
*   io.netcdf.netCDFUtil.java 
* 
* PURPOSE
*   To support variable attributes of netcdf file
* 
* DESCRIPTION
*   This class provides methods for writing variables with different data types
*   and dimensions. 
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 

package io.netcdf;

import java.io.*;
import ucar.ma2.*;
import ucar.nc2.*;


public class netCDFUtil {

    /**
     * Write a variable of byte[] to file
     * @param ncfile  - netcdf file to write 
     * @param varName - variable name
     * @param values  - variable values
     * @return 0 if successful, otherwise return -1. 
     */
     public static int writeByteVariable1D(NetcdfFileWriteable ncfile,String varName,byte[] values){
        try {
            ArrayByte.D1 datas = new ArrayByte.D1(values.length);
            for (int i=0;i<values.length;i++){
                datas.set(i,values[i]);
            }
            ncfile.write(varName, datas);
        } catch (IOException e) {
            System.err.println("ERROR writing  netCDFUtil::writeVariable1D:"+varName);
            return -1;
        } catch (InvalidRangeException e) {
            e.printStackTrace();
            return -1;
        }
        return 0;
    }

   /**
     * Write a variable of boolean to file
     * @param ncfile  - netcdf file to write 
     * @param varName - variable name
     * @param values  - variable value
     * @return 0 if successful, otherwise return -1. 
     */
     public static int writeBooleanVariable(NetcdfFileWriteable ncfile,String varName,boolean value){
        try {
            ArrayBoolean.D0 datas = new ArrayBoolean.D0();
            datas.set(value);
            ncfile.write(varName, datas);
        } catch (IOException e) {
            System.err.println("ERROR writing  netCDFUtil::writeShortVariable:"+varName);
            return -1;
        } catch (InvalidRangeException e) {
            e.printStackTrace();
            return -1;
        }
        return 0;
    }

    public static int writeShortVariable(NetcdfFileWriteable ncfile,String varName,short value){
        try {
            ArrayShort.D0 datas = new ArrayShort.D0();
            datas.set(value);
            ncfile.write(varName, datas);
        } catch (IOException e) {
            System.err.println("ERROR writing  netCDFUtil::writeShortVariable:"+varName);
            return -1;
        } catch (InvalidRangeException e) {
            e.printStackTrace();
            return -1;
        }
        return 0;
    }
 
 
       public static int writeIntVariable(NetcdfFileWriteable ncfile,String varName,int value){
        try {
            ArrayInt.D0 datas = new ArrayInt.D0();
            datas.set(value);
            ncfile.write(varName, datas);
        } catch (IOException e) {
            System.err.println("ERROR writing  netCDFUtil::writeShortVariable:"+varName);
            return -1;
        } catch (InvalidRangeException e) {
            e.printStackTrace();
            return -1;
        }
        return 0;
    }
 

}
