/*@***h* AMSU-A_FCDR_STAR/noaa.NOAADataSetPub.java
* NAME
*    noaa.NOAADataSetPub.java 
* 
* PURPOSE
*   To write climate data record in binary format.
* 
* DESCRIPTION
*   This class provide methods for writing climate data record in binary 
*   formats.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 
package noaa;


public class NOAADataSetPub {
    public static int putFloatFORTRAN(float value, byte[] buf,int offset){
        int intValue=Float.floatToIntBits(value);
        buf[offset]=(byte)(intValue & 0xff);
        buf[offset+1]=(byte)((intValue>>8)& 0xff);        
        buf[offset+2]=(byte)((intValue>>16)& 0xff);
        buf[offset+3]=(byte)((intValue>>24) & 0xff);        
        return 4;
    }

    public static int putFloat(float value, byte[] buf,int offset){
        int intValue=Float.floatToIntBits(value);
        return putInt(intValue,buf,offset);
    }
    
    public static int putShort(short value, byte[] buf,int offset){
        buf[offset]=(byte)((value>>8)& 0xff);
        buf[offset+1]=(byte)(value & 0xff);        
        return 2;
    }
    
    public static int putInt(int value, byte[] buf,int offset){
        buf[offset]=(byte)((value>>24)& 0xff);
        buf[offset+1]=(byte)((value>>16)& 0xff);        
        buf[offset+2]=(byte)((value>>8)& 0xff);
        buf[offset+3]=(byte)(value & 0xff);        
        return 4;
    }

    

/////////////////////////////////////////////////////////////////////
//Reverse    
    
    public static int putShort1(short value, byte[] buf,int offset){
        buf[offset+1]=(byte)((value>>8)& 0xff);
        buf[offset]=(byte)(value & 0xff);        
        return 2;
    }
    
    public static int putInt1(int value, byte[] buf,int offset){
        buf[offset+3]=(byte)((value>>24)& 0xff);
        buf[offset+2]=(byte)((value>>16)& 0xff);        
        buf[offset+1]=(byte)((value>>8)& 0xff);
        buf[offset]=(byte)(value & 0xff);        
        return 4;
    }


}
