/*@***h* AMSU-A_FCDR_STAR/pub.L1C.IMICACoefficient.java
* NAME
*   pub.L1C.IMICACoefficient.java 
* 
* PURPOSE
*   To define the IMICA calibration coefficients.
* 
* DESCRIPTION
*   This class defines IMICA calibration coefficients and related methods.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   03/20/2009
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   05/06/2011 - added time dependent constant offset and nonlinear coefficients.
*
*@*****/
 
 
package pub.L1C;


public class IMICACoefficient {
    public static final float time0=2001;  //for time-dependent costant offset kappa
    public static final double time1=1998; //for time-dependent non linear coefficient lamda
    public double delta0,   //constant offset
                  kappa,    //time dependent offset
                  fkappa,  //not used anymore
                  mu0,     //constant nonlinearity coefficients
                  lamda;   //time-depent nonlinearity coefficients
    
    public IMICACoefficient(){
         delta0=0;
         kappa=0;
         fkappa=1;
         mu0=0;
         lamda=0;
    }
    
    public void setMu0(float value){
        mu0=value;
    }
    public void setDelta0(float v){
        delta0=v;
    }
    public void setKappa(float v){
        kappa=v;
    }

    public void setKappaScalingFactor(float f){
        fkappa=f;
    }
    
    public void setLamda(float v){
        lamda=v;
    }

    @Override
    public String toString(){
        String str;
        
        str=String.format("Delta0=%6.4fe-5 Kappa=%6.4fe-5 Mu0=%6.4f Lamda=%6.4f", 
                -delta0*100000,-kappa*100000,mu0,lamda);
        return str;
    }
    
    public String toString(int channel){
        String str="ch"+(channel+1)+": "+toString();
        return str;
    }
}

