/*@***h* AMSU-A_FCDR_STAR/pub.L1C.L1CThread.java
* NAME
*   pub.L1C.L1CThread.java 
* 
* PURPOSE
*   To define a supper class for supporting concurrent generation of level 1c 
*   radiance FCDR.
* 
* DESCRIPTION
*   This class is the supper class for AMSUAL1CThreadNetCDF, SSUL1CThreadNetCDF.
*   It also defines and manages level 1c file scan line statistics.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   09/23/2009
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry.
*
*@*****/



package pub.L1C;

import io.FileLog;


public class L1CThread extends Thread{
     //for level 1c statistics
    protected static float nScanlineTotal=0;  //total number of scan lines
    protected static float nGood=0;           //total number of good scan lines
    protected static float nBadRawCounts=0;   //total number of bad raw counts
    protected static float nBadPrecip=0;      //total number of precipitation pixels
    protected static float nBadGeo=0;         //total number of pixels with bad geolocation information
    
    protected static FileLog fpLog=null;      //log file



    @Override
    public void run(){
    }
    
    /**
     * Suspend a thread 
     */
    void randomWait(){
        try{
            sleep((long)(5000*Math.random()));
        }catch(InterruptedException e){
            System.out.println("Interrupted");
        }
    }   
    
    /**
     * Update scanline statistics
     * @param nTotal0 - total number of scan lines
     * @param nGood0  - total number of good scan lines
     * @param nBadRawCounts0 - total number of bad raw counts
     * @param nBadPrecip  - total number of precipitation pixels
     */
    public static synchronized void updateScanlineCounter(float nTotal0, float nGood0,
            float nBadRawCounts0, float nBadPrecip) {
        nScanlineTotal += nTotal0;
        nGood += nGood0;
        nBadRawCounts += nBadRawCounts0;
    }

    /**
     * Get total number of scan lines
     * @return total number of scan lines
     */
    static public float getTotalScanlines() {
        return nScanlineTotal;
    }

    
   /**
     * Get total number of good scan lines
     * @return total number of good scan lines
     */
    static public float getTotalGoodScanline() {
        return nGood;
    }    
}
