/*@***h* AMSU-A_FCDR_STAR/pub.variable.VariableControl.java
* NAME
*   pub.variable.VariableControl.java 
* 
* PURPOSE
*   To regulate what variables will be generated in various CDR products.
* 
* DESCRIPTION
*   This class defines identifiers of different values in various CDR products,
*   as well as methods to set and get flags that control if a particular variable
*   will be generated or not.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   09/23/2009
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   05/13/2013 - moved to pub.variable package from pub for a better code 
*                organization.
*
*@*****/
 


package pub.variable;


public class VariableControl {
    //INDEX for different tempreatures
    static public final short T_INDEX_SNO=0;
    static public final short T_INDEX_SNO_LIMB=1;
    static public final short T_INDEX_OPR=2;
    static public final short T_INDEX_OPR_LIMB=3;
    static public final short T_INDEX_LINEAR=4;
    static public final short T_INDEX_LINEAR_LIMB=5;    
    static public final short T_INDEX_TMTALTEFFECTCORRECTED_SNO=6;
    static public final short T_INDEX_TMTALTEFFECTCORRECTED_OPR=7;
     
    //SSU temperature variables
    static public final short T_INDEX_OPR_SSU=0;
    static public final short T_INDEX_OPR_SSU_CELLPRESCORRS=1;
    static public final short T_INDEX_OPR_SSU_CELLPRESCORRS_O2=2;
    static public final short T_INDEX_OPR_SSU_CELLPRESCORRS_O2_LIMB=3;
    static public final short T_INDEX_OPR_SSU_CELLPRESCORRS_O2_LIMB_DIUR=4;
    static public final short T_INDEX_LINEAR_STAR=5;
   //FOR SSU
    
    
    //BIT DEFINITION FOR EACH TEMPERATURE IN THE CONTROL 
    public static final int CONTROL_T_LINEAR=1;
    public static final int CONTROL_T_OPR=1<<1;
    public static final int CONTROL_T_SNO=1<<2;
    public static final int CONTROL_T_LINEAR_LIMB=1<<3;
    public static final int CONTROL_T_OPR_LIMB=1<<4;
    public static final int CONTROL_T_SNO_LIMB=1<<5;
    
     
    public static final int CONTROL_WT=1<<6;
    public static final int CONTROL_RAWCOUNTS=1<<7;
    public static final int CONTROL_GEOMETRY=1<<8;
    public static final int CONTROL_ATTITUDE=1<<9;

    static public final int CONTROL_TMTALTEFFECTCORRECTED_SNO=1<<10; 
    static public final int CONTROL_TMTALTEFFECTCORRECTED_OPR=1<<11;
    
    static public final int CONTROL_SATELLITE_ATTITUDE=1<<12;
    static public final int CONTROL_CALIBRATION_COEFFICIENTS=1<<13;
    static public final int CONTROL_LECT=1<<14;
    static public final int CONTROL_ASD_FLAG=1<<15;   

    static public final int CONTROL_TIME_NOAAL1BFORMAT=1<<16;   
    static public final int CONTROL_TIME_TIME_ISO8601=1<<17;   
    static public final int CONTROL_TIME_SINCE1978=1<<18;   
    //END BIT DEFINITIONS
    ///////////////////////////////////////////
    
    public static final int[] controlTs={
                        CONTROL_T_SNO,
                        CONTROL_T_SNO_LIMB,
                        CONTROL_T_OPR,
                        CONTROL_T_OPR_LIMB,
                        CONTROL_T_LINEAR,
                        CONTROL_T_LINEAR_LIMB,
                        CONTROL_TMTALTEFFECTCORRECTED_SNO,
                        CONTROL_TMTALTEFFECTCORRECTED_OPR,
                       };


    

    static public int control=0xffffffff
                              //-CONTROL_RAWCOUNTS
                              -CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              //-CONTROL_T_OPR_LIMB-
                              -CONTROL_GEOMETRY;  //default write all variables
    
        
    static public final int controlAMSUAL1CR20=0xffffffff
                              -CONTROL_RAWCOUNTS
                              -CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              //-CONTROL_T_SNO-CONTROL_T_SNO_LIMB;
                              //-CONTROL_T_OPR_LIMB;//-CONTROL_T_OPR;
                              //CONTROL_GEOMETRY;  //default write all variables
                              -CONTROL_CALIBRATION_COEFFICIENTS
                              -CONTROL_LECT
                              -CONTROL_ASD_FLAG
                              -CONTROL_TIME_NOAAL1BFORMAT;
                              
    static public int controlL1CDefault=0xffffffff
                              //-CONTROL_RAWCOUNTS
                              -CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              //-CONTROL_T_SNO-CONTROL_T_SNO_LIMB;
                              //-CONTROL_T_OPR_LIMB;//-CONTROL_T_OPR;
                              //CONTROL_GEOMETRY;  //default write all variables
                              -CONTROL_CALIBRATION_COEFFICIENTS
                              //-CONTROL_LECT
                              //-CONTROL_ASD_FLAG;
                               ;
    
   static public int controlL1CDefaultOPR=0xffffffff
                              //-CONTROL_RAWCOUNTS
                              -CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              -CONTROL_T_SNO-CONTROL_T_SNO_LIMB;
                              ;//-CONTROL_T_OPR_LIMB;//-CONTROL_T_OPR;
                              //CONTROL_GEOMETRY;  //default write all variables
   static public int controlL1CDefaultSNO=0xffffffff
                              //-CONTROL_RAWCOUNTS
                              -CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              -CONTROL_T_OPR-CONTROL_T_OPR_LIMB
                              -CONTROL_RAWCOUNTS
                              -CONTROL_GEOMETRY;
                              ;//-CONTROL_T_OPR_LIMB;//-CONTROL_T_OPR;
                              //CONTROL_GEOMETRY;  //default write all variables

   
    static public final short CONTROL_T_SSU=0x03f | CONTROL_WT | CONTROL_RAWCOUNTS | CONTROL_CALIBRATION_COEFFICIENTS;
    static public int controlSSUL3=CONTROL_T_SSU;
    static public int controlL1CDefaultSSU=0xffffffff
                              //-CONTROL_RAWCOUNTS
                              //-CONTROL_T_LINEAR-CONTROL_T_LINEAR_LIMB
                              -CONTROL_T_SNO-CONTROL_T_SNO_LIMB
                              //-CONTROL_T_OPR_LIMB  -- SSU_Rad
                              //-CONTROL_T_OPR;         SSU_BT
                              -CONTROL_SATELLITE_ATTITUDE; //CONTROL_GEOMETRY;  //default write all variables
  
    static public final short CONTROL_T_HIRS=0x03f | CONTROL_WT | CONTROL_RAWCOUNTS | CONTROL_CALIBRATION_COEFFICIENTS;
    static public int controlHIRSL3=CONTROL_T_HIRS;
   
   //predefined controls;
    static public int controlLevel3Default= CONTROL_T_OPR+CONTROL_T_OPR_LIMB+CONTROL_T_SNO+CONTROL_T_SNO_LIMB+CONTROL_WT;
                                               
    static public int controlLevel3LIMBEXP=CONTROL_T_SNO+CONTROL_T_SNO_LIMB;  //48
    //static public int controlLevel3LIMBEXP=CONTROL_T_OPR+CONTROL_T_OPR_LIMB;  //48
    
    
    static public void setAMSUALevel1R2OControl() {
        control = 0x0fffffff;
        control -= CONTROL_RAWCOUNTS;
        control-=(CONTROL_T_LINEAR | CONTROL_T_LINEAR_LIMB);
                //-CONTROL_T_SNO-CONTROL_T_SNO_LIMB;
                //-CONTROL_T_OPR_LIMB;//-CONTROL_T_OPR;
                //CONTROL_GEOMETRY;  //default write all variables
        control-= CONTROL_CALIBRATION_COEFFICIENTS;
        control-= CONTROL_LECT;
        control-= CONTROL_ASD_FLAG;
        control-= CONTROL_SATELLITE_ATTITUDE;
        control-= CONTROL_TIME_NOAAL1BFORMAT;

    }
    static public void setPredefinedControl(int predefinedControl){
        control=predefinedControl;
    }
    
    static public void setControl(int c,boolean bSet){
        if (bSet){
            control=control | c;
        }else{
            control=control & (~c);
        }
    }
    
    static public int getControl(){
        return control;
    }
    
    static public void setAquaControl(){
        //control=0xffffffff;
        setControl(CONTROL_T_LINEAR,false);
        setControl(CONTROL_T_LINEAR_LIMB,false);
        setControl(CONTROL_T_SNO,false);
        setControl(CONTROL_T_SNO_LIMB,false);
        setControl(CONTROL_RAWCOUNTS,false);

    }
//////////////////////////////////////////////////////////
    static public boolean isWriteT(int indexT){
        return (control & controlTs[indexT])!=0;
    }
 /*    
    static public boolean bWriteT_LINEAR(){
        return (control & CONTROL_T_LINEAR)!=0;
    }
    
    static public boolean bWriteT_LINEAR_LIMB(){
        return (control & CONTROL_T_LINEAR_LIMB)!=0;
    }

    static public boolean bWriteT_SNO(){
        return (control & CONTROL_T_SNO)!=0;
    }
    
    static public boolean bWriteT_SNO_LIMB(){
        return (control & CONTROL_T_SNO_LIMB)!=0;
    }
    
    static public boolean bWriteT_OPR(){
        return (control & CONTROL_T_OPR)!=0;
    }
    
    static public boolean bWriteT_OPR_LIMB(){
        return (control & CONTROL_T_OPR_LIMB)!=0;
    }
*/
    static public boolean isWriteLECT(){
        return (control & CONTROL_LECT)!=0;
    }
    static public boolean isWriteASDFlag(){
        return (control & CONTROL_ASD_FLAG)!=0;
    }
    static public boolean isWriteRawCount(){
        return (control & CONTROL_RAWCOUNTS)!=0;
    }
    static public boolean isWriteCalibrationCoefficients(){
        return (control & CONTROL_CALIBRATION_COEFFICIENTS) !=0;
    }
    static public boolean isWriteWT(){
        return (control & CONTROL_WT)!=0;
    }
    
    static public boolean bUseLinearCalibration(){
        return isWriteT(T_INDEX_LINEAR) || isWriteT(T_INDEX_LINEAR_LIMB);
    }
    static public boolean bUseOPRCalibration(){
        return isWriteT(T_INDEX_OPR) || isWriteT(T_INDEX_OPR_LIMB);
    }
    static public boolean bUseSNOCalibration(){
          return isWriteT(T_INDEX_SNO) || isWriteT(T_INDEX_SNO_LIMB);
    }
    static public boolean bUseLimbCorrection(){
         return isWriteT(T_INDEX_SNO_LIMB) || isWriteT(T_INDEX_OPR_LIMB) || isWriteT(T_INDEX_LINEAR_LIMB);
    }
    
    static public int getNumCalibrationMethodsUsed(){
        int n=0;
        if (bUseLinearCalibration())
            n++;
        if (bUseOPRCalibration())
            n++;
        if (bUseSNOCalibration())
            n++;
        return n;
    }
    
    static public boolean isWriteSatelliteAttitude(){
        return (control & CONTROL_SATELLITE_ATTITUDE)!=0;
    }
    static public boolean isWriteGeometry(){
        return (control & CONTROL_GEOMETRY)!=0;
    }
 
    static public boolean isWrittenTimeISO8601() {
        return (control & CONTROL_TIME_TIME_ISO8601) != 0;
    }

    static public boolean isWrittenTimeSince1978() {
        return (control & CONTROL_TIME_SINCE1978) != 0;

    }

    static public boolean isWrittenTimeNOAAL1BFORMAT() {
        return (control & CONTROL_TIME_NOAAL1BFORMAT) != 0;
    }
    
    static public void printStatus(){
           System.out.println("T_SNO="+isWriteT(T_INDEX_SNO));
        System.out.println("T_SNO_LIMB="+isWriteT(T_INDEX_SNO_LIMB));
        System.out.println("T_OPR="+isWriteT(T_INDEX_OPR));
        System.out.println("T_OPR_LIMB="+isWriteT(T_INDEX_OPR_LIMB));
        System.out.println("T_LINEAR="+isWriteT(T_INDEX_LINEAR));
        System.out.println("T_LINEAR_LIMB="+isWriteT(T_INDEX_LINEAR_LIMB));
        System.out.println("bGenerateRawCountProduct="+isWriteRawCount());
        System.out.println("bGenerateGeometryVariables="+isWriteGeometry());
    }
 
}
