/*@***h* AMSU-A_FCDR_STAR/util.ParserUtil.java
* NAME
*   util.ParserUtil.java 
* 
* PURPOSE
*   To provide methods for parsing binary format datasets.
* 
* DESCRIPTION
*   This class provides methods for supporting parsing binary format datasets,
*   such as NOAA binary format level 1b products.
*  
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 

package util;

public class ParserUtil {
    /**
     * Combine two bytes into a integer
     * @param b1 - first byte
     * @param b2 - second byte
     * @return integer represented by the two bytes
     */
    static public int combineInteger2(byte b1,byte b2){
        int temp=(b1 & 0xff);
        temp<<=8;
        temp+=(b2&0x0ff);
        return temp;
    }
    
    /**
     * Combine four bytes into a integer
     * @param b1 - first byte
     * @param b2 - second byte
     * @param b3 - 3nd byte
     * @param b4 - fourth byte
     * @return integer represented by the four bytes
     */
    static public int combineInteger4(byte b1,byte b2,byte b3,byte b4){
        int temp=(b1 & 0xff);
        temp<<=8;
        temp+=(b2&0x0ff);
        temp<<=8;
        temp+=(b3&0x0ff);
        temp<<=8;
        temp+=(b4&0x0ff);
        return temp;
    }

    /**
     * Convert 4 bytes to a float number
      * @param b1 - first byte
     * @param b2 - second byte
     * @param b3 - 3nd byte
     * @param b4 - fourth byte
     * @return float number
     */
    static public float combineFloat(byte b1,byte b2,byte b3,byte b4){
       int temp;       
        temp=(b4 & 0xff);
        temp<<=8;
        temp+=(b3&0x0ff);
        temp<<=8;
        temp+=(b2&0x0ff);
        temp<<=8;
        temp+=(b1&0x0ff);
        
        float value=Float.intBitsToFloat(temp);
  
        return value;
    }

}
