/*@***h* AMSU-A_FCDR_STAR/util.StringUtil.java
* NAME
*    util.StringUtil.java 
* 
* PURPOSE
*   To provide methods for string manupulations.
* 
* DESCRIPTION
*   This calls provides some convinient static methods for string manupulations.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   10/10/2008
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry.
*
*@*****/
 


package util;


public class StringUtil {

    /**
     * Extract direction info. from a full pathname
     * @param fullpath - full pathname
     * @return directory name
     */
    static public String getDirectory(String fullpath){
      byte[] str=fullpath.getBytes();
        int i;
        String dir;
        
        i=fullpath.length()-1; 
        while (i>=0 && str[i]!='/' && str[i]!='\\') 
            i--;
 
        dir=fullpath.substring(0, i-1);
        return dir;       
    }
    
    /**
     * Extract file name from a full pathname
     * @param fullpath - full pathname
     * @return file name
     */
    static public String getFilename(String fullpath){
        byte[] str=fullpath.getBytes();
        int i,ii;
        String name;
        
        i=fullpath.length()-1; 
        while (i>=0 && str[i]!='/' && str[i]!='\\') 
            i--;
        ii=fullpath.length()-1;
        while (!Character.isLetter(str[ii]))
		 ii--;
        name=fullpath.substring(i, ii);
        return name;
    }  
    
    /**
     * Convert a integer to a string of length >=3.
     * If the integer is less than 100, '0's is added in the beginning of the string.
     * @param n - integer
     * @return string converted from the integer.
     */
    public static String toString3(int n){
        String str;
        if (n>=100){
            str=""+n;
        }else if (n>=10){
            str="0"+n;
        }else 
            str="00"+n;
        return str;
    }

    /**
     * Convert a integer to a string of length >=2.
     * If the integer is less than 10, '0's is added in the beginning of the string.
     * @param n - integer
     * @return string converted from the integer.
     */
    public static String toString2(int n){
        String str;
        if (n>=10){
            str=""+n;
        }else {
            str="0"+n;
        }
        return str;
    }

 
    /**
     * Combine a String Array to a single string, separated by a separator 
     * @param strs - String Array
     * @param sep - separator
     * @return - combined string
     */
    public String combineStrings(String[] strs,String sep){
        String res="";
        for (int i=0;i<strs.length;i++){
            if (i>0)
                res+=sep;
            res+=strs[i];
        }
        return res;
    }

    /**
     * Make a string of a given lengh 
     * @param ch - char to be used in the string
     * @param length - length of the string
     * @return string 
     */
    public static String makeDummyString(char ch,int length){
        String str="";
        for (int i=0;i<length;i++){
            str+=ch;
        }
        return str;
    }
}


