/*@***h* AMSU-A_FCDR_STAR/util.Time.java
* NAME
*   util.Time.java 
* 
* PURPOSE
*   To support time.
* 
* DESCRIPTION
*   This class provides constant, variables, and methods for time manipulation
*   time format conversions.
*   The primary time format used in the CDR is year, day of year, millisecond of year.
*   It also support other time format, such as ISO 8601, referenced or elapsed 
*   time format, or year-month-day hour-minute-second.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   09/01/2008
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
*   03/05/2010 Initial version developed for the 2010 Workshop on Climate Data Records
*              from Satellite Microwave Radiometry.
*
*@*****/
 
 
package util;


import java.text.SimpleDateFormat;
import java.util.Calendar;

public class Time {
    public static final int[] daysNoLeap={31,28,31,30,31,30,31,31,30,31,30,31};
    public static final int[] daysLeap={31,29,31,30,31,30,31,31,30,31,30,31};
    public static final int[] startDayOfYearForMonthNonLeap={1,32,60,91,121,152,182,213,244,274,305,335};
    
    public static final long SECONDS_PER_YEAR_NOLEAP=365*24*60*60;
    public static final long SECONDS_PER_YEAR_LEAP=366*24*60*60;
    public static final int SECONDS_PER_DAY=24*60*60;
    public static final int MILLISECONDS_PER_DAY=SECONDS_PER_DAY*1000;
    public static final long MILLISECONDS_PER_YEAR_NOLEAP=SECONDS_PER_YEAR_NOLEAP*1000;
    public static final long MILLISECONDS_PER_YEAR_LEAP=SECONDS_PER_YEAR_LEAP*1000;
   

    public short year;
    public short dayOfYear;
    public int millisecondOfDay;
    
    byte month;
    byte pentad;
    byte day;
    byte hour;
    byte minute;
    byte second;
	
    
    float ftimeOfDay;

    public Time(){
        init();
   
    }
    
    public Time(short year,short jday,int milliscond){
        this.year=year;
 
        setDayOfYear(jday);
        setMillisecondOfDay(milliscond);

      }
    
    public Time(int year,int month,int pentad){
        this.year=(short)year;
        this.month=(byte)month;
        this.pentad=(byte)pentad;
    }
    
    public void init(){
         year=0;
         dayOfYear=0;
         millisecondOfDay=0;
         
         month=0;
        pentad=0;
       
    }
    
 //   public boolean isValid(){
 //       return year>0 && dayOfYear>1 && millisecondOfDay>0 
 //   }
    
    public void set(Time t){
        year=t.getYear();
        setDayOfYear(t.getDayOfYear());
        setMillisecondOfDay(t.getMillisecondOfDay());
        /*other variables will be add later*/
    }
    
    
    
    //used by SSU
    public void setFractionalYear(double fyear){
        year=(short)fyear;
        int nDays=Time.isLeapYear(year)?366:365;
        
        double f=(fyear-year)*nDays*MILLISECONDS_PER_DAY;
        this.setDayOfYear((short)(f/MILLISECONDS_PER_DAY+1));
        f-=((double)dayOfYear-1)*MILLISECONDS_PER_DAY;
        setMillisecondOfDay((int)(f));
         if (!isValid()){
           System.out.println(toString());
           System.exit(-1);
        }
    }
    public void setYear(short year){
        this.year=year;
    }
    public void setMonth(byte month){
        this.month=month;
    }
    public void setDayOfYear(short d){
        dayOfYear=d;
        
	byte[] days={31,28,31,30,31,30,31,31,30,31,30,31};
	short i,n=0;
	if (Time.isLeapYear(year))
		days[1]=29;

       
        month=1;
        while (d>days[month-1] && month<12){
            d-=days[month-1];
            month++;
        }
        
        if (d>days[month-1]){
            //System.out.println("year="+year+" Feb="+days[1]);
            //System.out.println("Invalid day of year day="+d+" month="+month);
        }
        
        day=(byte)d;
    
    }
    
    

    public void setMillisecondOfDay(int millisec){        
        millisecondOfDay=millisec;
        hour=(byte)(millisec/60/60000);
        
        minute=(byte)((millisec-hour*60*60000)/60000);
        
        second=(byte)((millisec%60000)/1000+0.5);
        ftimeOfDay=((float)millisec)/MILLISECONDS_PER_DAY;
    }
    
    
    public static int calculateNumberOfDays(Time t1, Time t2){
        int n=0;
        Time t=new Time();
        t.set(t1);
        
        while (t.compareYearAndDay(t2) <=0 ){
            n++;
            t=t.nextDay();
        }
        
        return n;
    }   
    
    public static short convertTwoDigitYear2FourDigitYear(short y2){
        int y4;
        if (y2<50)
            y4=2000+y2;
        else
            y4=1900+y2;
        return (short)y4;
    }
    public void set(short year,short jday, int millisecond){
        this.year=year;
         this.setDayOfYear(jday);
        this.setMillisecondOfDay(millisecond);
    }
    
    public static void calPentadStartEndJulianDay(int year,int ipentad,short[] jdays){
        jdays[0]=(short)((ipentad-1)*5+1);
        jdays[1]=(short)(jdays[0]+4);
        if (jdays[1]==365 && isLeapYear(year))
            jdays[1]++;        
    }
    public static String getDayOfYearString3(int day){
        String str;
        if (day>100){
            str=""+day;
        }else if (day>10){
            str="0"+day;
        }else 
            str="00"+day;
        return str;
    }
    
    public short getYear() {return year;}
    public short getYear2Digit(){
        if (year<100)
            return year;        
        short year1=(short)(year%100);
        if (year1<10)
            year1+=2;
        return year1;        
    }
    public short getDayOfYear() {return dayOfYear;}
    public int getMillisecondOfDay() {return millisecondOfDay;}
    
    public float getFtimeOfDay() {return ftimeOfDay;}
    public void setFtimeOfDay(float t) {ftimeOfDay=t;}
    public int getMonth() {return month;}
    public int getDay() {return day;}
    public int getHour() {return hour;}
    public int getMinute() {return minute;}
    public int getSecond() {return second;}
    
    public int compareYearAndDay(Time t){
	if (year>t.getYear())
		return 1;
	else if (year<t.getYear())
		return -1;
	if (dayOfYear>t.getDayOfYear())
		return 1;
	else if (dayOfYear<t.getDayOfYear())
		return -1;
	return 0;
    }


    public int compare(Time t){
	int result=compareYearAndDay(t);
	if (result==0){
		if (t.getFtimeOfDay()>getFtimeOfDay())
			return -1;
		else if(t.getFtimeOfDay()<getFtimeOfDay())
			return 1;
		else
			return 0;
	}else {
		return result;

	}
    }

    //year, jday, milisecond of day
    public int compare1(Time t){
	int result=compareYearAndDay(t);
        int sec1,sec2;
	if (result==0){
            sec1=this.getMillisecondOfDay();
            sec2=t.getMillisecondOfDay();
            if (sec2>sec1)
		return -1;
	    else if(sec2<sec1)
		return 1;
	    else
		return 0;
	}else {
		return result;

	}
    }

    public void set(java.util.Date date) {
        set((int) date.getYear(), (int) date.getMonth(), (int) date.getDay(),
                (int) date.getHours(), (int) date.getMinutes(), (int) date.getSeconds());

    }

    public void set(int year1,int month1,int day1,int hour1,int minute1,int second1){
	this.year=(short)year1;
	this.month=(byte)month1;
	this.day=(byte)day1;
	this.hour=(byte)hour1;
	this.minute=(byte)minute1;
	this.second=(byte)second1;
	
	ftimeOfDay=hour+minute/60.0f+second/3600.0f;
	dayOfYear=monthDay2DayOfYear(year,month,day);	
        millisecondOfDay=((int)second+minute*60+hour*60*60)*1000;
    }

    public void set(int year1,int dayOfYear1,int hour1,int minute1,int second1){
	this.year=(short)year1;
	dayOfYear=(short)dayOfYear1;		
	this.hour=(byte)hour1;
	this.minute=(byte)minute1;
	this.second=(byte)second1;
	
	ftimeOfDay=hour+minute/60.0f+second/3600.0f;
    }
    public void set(int year1,int dayOfYear1,float ftimeOfDay1){
	this.year=(short)year1;
	dayOfYear=(short)dayOfYear1;		
	ftimeOfDay=ftimeOfDay1;
    }

    public static boolean isLeapYear(int year){
	return (year%4==0 && (year%100!=0 || year%400==0));
    }

    public static int getNumberOfDayOfMonth(int year, int month){
        if (isLeapYear(year)){
            return daysLeap[month-1];
        }else
            return daysNoLeap[month-1];
    }
    
    public static int getFirstDayOfYear(int year,int month){
        //System.out.println("Time::getFirstDayOfYear month="+month);
        int day=startDayOfYearForMonthNonLeap[month-1];
        if (isLeapYear(year) && month>2){
            day++;
        }
        return day;
    }
    
    public static int getLastDayOfYear(int year,int month){
        int day= getFirstDayOfYear(year,month);
        int n=Time.getNumberOfDayOfMonth(year, month);
        return day+n-1;       
    }

    public static short monthDay2DayOfYear(int year,int month,int day){
	byte[] days={31,28,31,30,31,30,31,31,30,31,30,31};
	short i,n=0;
	if (year%4==0 && (year%100!=0 || year%400==0))
		days[1]=29;
	for (i=1;i<month;i++){
		n+=days[i-1];
	}
	n+=day;
	return n;
    }

     
    public Time nextDay(){
	Time time=new Time();
	int lastDay=365;
	int day1;
	int offsetYear=0;
	
	if (isLeapYear(year))
		lastDay=366;
	day1=dayOfYear+1;
	if (day1>lastDay){
		day1=1;
		offsetYear=1;
	}
		
	time.set(this.year+offsetYear,day1,0);
	return time;
    }

    public void adjust(float offset){
	ftimeOfDay+=offset;
	while (ftimeOfDay>=24.0f){
		ftimeOfDay-=24;
		dayOfYear++;
	}
	while (ftimeOfDay<0){
		ftimeOfDay+=24;
		dayOfYear--;
	}
	
	if (dayOfYear<1){
		year--;
		if (isLeapYear(year))
			dayOfYear+=366;
		else
			dayOfYear+=365;		
	}
    }


    public static float localSolarTimeToGMT(float localSolarTime, float lon){
	float delta=-lon/15.0f;
	float ftime=localSolarTime;

	ftime+=delta;
	if (ftime>=24.0){
		ftime-=24.0;
	}else if (ftime<0.0){
		ftime+=24.0;
	}
	return ftime;
    }
    
    public static float GMT2LocalSolarTime(float gmt,float lon){
        float delta=lon/15.0f;	
	float ftime=gmt;

	ftime+=delta;
	if (ftime>=24){
		ftime-=24;
	}else if (ftime<0){
		ftime+=24;
	}
	return ftime;   
    }
    public static float GMT2LocalSolarTime(float dayOfYear,float gmt,float lon){
        //http://pvcdrom.pveducation.org/SUNLIGHT/SOLART.HTM 
        //http://www.theorderoftime.com/solartime2.html a online caculator
        //dayOfYear start from 0-365
        double dtgmt;
        if (lon>=0){
            dtgmt=Math.ceil((lon-7.5)/15.0f);
        }else{
            dtgmt=Math.floor((lon-7.5)/15.0f);
        }
        //dtgmt=(lon)/15.0f;
        double localTime=gmt+dtgmt; //(lon)/15.0f;
        if (localTime<0){
            localTime+=24;
            dayOfYear--;
        }else if (localTime>=24){
            localTime-=24;
            dayOfYear++;
        }

        double lstm=15*dtgmt;  //local standard time meridian
        //lstm=localTime-gmt;
        double b=(360.0f/365)*(dayOfYear-81)*2*Math.PI/360;
        double eot=9.87*Math.sin(2*b)-7.53*Math.cos(b)-1.5*Math.sin(b);
        double tc=4*(lon-lstm)+eot;   //in minute
        
        double lst=localTime+tc/60;
        if (lst<0){
            lst+=24;
        }else if (lst>=24)
            lst-=24;
        
        return (float)lst;
    }

    //given local solar time, calculate GMT time
    public static float LocalSolarTime2GMT(float dayOfYear,float lst,float lon){
        //http://pvcdrom.pveducation.org/SUNLIGHT/SOLART.HTM 
        //http://www.theorderoftime.com/solartime2.html a online caculator
        //dayOfYear start from 0-365
        double dtgmt,gmt/*gmt*/;
        if (lon>=0){
            dtgmt=Math.ceil((lon-7.5)/15.0f);
        }else{
            dtgmt=Math.floor((lon-7.5)/15.0f);
        }
        double lstm=15*dtgmt;  //local standard time meridian
        //lstm=localTime-gmt;
        double b=(360.0f/365)*(dayOfYear-81)*2*Math.PI/360;
        double eot=9.87*Math.sin(2*b)-7.53*Math.cos(b)-1.5*Math.sin(b);
        
        double tc=4*(lon-lstm)+eot;   //in minute

        double localTime=lst-tc/60;
        gmt=localTime-dtgmt;
        
        if (gmt<0){
            gmt+=24;
            dayOfYear--;
        }else if (gmt>=24){
            gmt-=24;
        }

        
        return (float)gmt;
    }
    
    
    static public short getJulianDayStart(short year,short month){
        short jday=1;
        int m=1;
        int[] days;
        if (Time.isLeapYear(year))
            days=daysLeap;
        else
            days=daysNoLeap;
        while (m<month){
            jday+=days[m-1];
            m++;
        }
        return jday;
    } 
    
    static public short getJulianDayEnd(short year,short month){
        short jday=getJulianDayStart(year,month);
        int[] days;
        if (Time.isLeapYear(year))
            days=daysLeap;
        else
            days=daysNoLeap;
        jday+=days[month-1]-1;
        return jday;
    } 
    
   public static long getSecondsSince(int sinceWhen,int year,int dayOfYear,int secondOfDay){
        long sum=0;
        
        int y=sinceWhen;
        while (y<year){
            if (isLeapYear(y))
                sum+=SECONDS_PER_YEAR_LEAP;
            else
                sum+=SECONDS_PER_YEAR_NOLEAP;
            y++;
        }
        
        sum+=(dayOfYear-1)*SECONDS_PER_DAY;
        sum+=secondOfDay;
        
        return sum;
    }  
   
    public static float calFYear(short year,short dayOfYear,int milliSecondsOfDay){
        float ftime;
        int n;
        if (isLeapYear(year))
            n=366;
        else n=365;
        ftime=milliSecondsOfDay/60000/60/24;
        ftime+=dayOfYear;
        ftime/=n;
        ftime+=year;
        return ftime;
    }
    public float calFYear(){
        return calFYear(year,dayOfYear,millisecondOfDay);
   
    }

    @Override
    public String toString(){
        String str="year="+year+" dayOfYear="+dayOfYear+" millisecondOfDay="+millisecondOfDay;
        return str;
    }
    
    public static String int2String(int value,int len){
        String str="";
        int n=(int)Math.log10(value);
        
        for (int i=0;i<len-1-n;i++)
            str+="0";
        str+=value;
        return str;
        
    }
    public String getYearString2(){
        short year2=(short)(year%100);
        String str=int2String(year2,2);
        return str;
    }

    public String getDayOfYearString(){
        String str=int2String(dayOfYear,3);
        return str;
    }

    public String getHourMinuteString(){
        String str=int2String(hour,2)+int2String(minute,2);
        return str;
    }
    
///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////
//Quality Control
    short getDayOfYearMax(){
        if (isLeapYear(year))
            return 366;
        else
            return 365;
    }
    
    long getMillisecondOfDayMax(){
        if (isLeapYear(year))
            return MILLISECONDS_PER_YEAR_LEAP;
        else
            return MILLISECONDS_PER_YEAR_NOLEAP;
        
    }
    
    
    public boolean isValid(){
        if (year<1978)
            return false;
        int dayMax=getDayOfYearMax();
        if (dayOfYear<1)
            return false;
        if (dayOfYear>dayMax+1)
            return false;
        if (dayOfYear==dayMax+1 && millisecondOfDay>0)//367, millisecond==0 is OK
            return false;
        if (millisecondOfDay<0 || millisecondOfDay>MILLISECONDS_PER_DAY)
            return false;
        return true;
    }
    
    public boolean isValidTOVSTime(short yearRef){
        boolean bValid=isValid();
        if (bValid){
            bValid=year<2007;
            if (bValid){
                bValid=year>=yearRef-1 && year<=yearRef+1;
            }
        }
        return bValid;
    }
    
    public static String getCurrentSystemTime(){
        String DATE_FORMAT_NOW = "yyyy-MM-dd HH:mm:ss";

        Calendar cal = Calendar.getInstance();
        SimpleDateFormat sdf = new SimpleDateFormat(DATE_FORMAT_NOW);
        return sdf.format(cal.getTime());

  }

    /**
     * Get milliseconds since a specified year
     * @param since - start year
     * @return milliseconds since a specified year
     */
    public double getMillisecondsSince(short since){
        double ret=caliculateEpoch(year,dayOfYear,millisecondOfDay,since);
        return ret;
    }

    public double getSecondsSince(short since){
        return getMillisecondsSince(since)/1000;
    }
    public void SetByMillisecondsSince(double millisec0,short since){
        double millisec=millisec0;
        year=since;
        long millisecYear=isLeapYear(year)?MILLISECONDS_PER_YEAR_LEAP:MILLISECONDS_PER_YEAR_NOLEAP;
        while (millisec >= millisecYear){
            year++;
            millisec-=millisecYear;
            millisecYear=isLeapYear(year)?MILLISECONDS_PER_YEAR_LEAP:MILLISECONDS_PER_YEAR_NOLEAP;
        }
        
        short jday=1;
        while (millisec >=MILLISECONDS_PER_DAY){
            jday++;
            millisec-=MILLISECONDS_PER_DAY;
        }
        setDayOfYear(jday);        
        setMillisecondOfDay((int)millisec);
     }
    
     public void setBySecondsSince(double seconds,short since){
         seconds*=1000;
         SetByMillisecondsSince(seconds,since);
     }
    
    public static double caliculateEpoch(short year,short dayOfYear,long millisecondOfDay,short since){
      double epoch=0,temp;
      short year1=since;
      while (year1<year){
          if (isLeapYear(year1)){
            epoch+=Time.MILLISECONDS_PER_YEAR_LEAP;
          } else{
            epoch+=Time.MILLISECONDS_PER_YEAR_NOLEAP;
          }
          year1++;
      }
      temp=(dayOfYear-1);
      temp*=Time.MILLISECONDS_PER_DAY;
      epoch+=temp;
      epoch+=millisecondOfDay;
      return epoch;      
  }
    
  
  public void setFromEpoch(double epoch,short year0){
 	long secondPerDay=24*60*60;
	long secondPerYearLeap=secondPerDay*366;
	long secondPerYearNoLeap=secondPerDay*365;
	long secondPerYear;
	
	double temp=0;
	
	year=year0;
	while (temp<epoch){
		if (isLeapYear(year))
			secondPerYear=secondPerYearLeap;
		else
			secondPerYear=secondPerYearNoLeap;
		if (temp+secondPerYear<epoch){
			temp+=secondPerYear;
			year++;
		}else{
			epoch-=temp;			
			temp=0;
			dayOfYear=1;
			while (temp+secondPerDay<epoch){
				dayOfYear++;
				temp+=secondPerDay;
			}                       
			int secondInDay=(int)(epoch-temp+0.5);
                        
                        this.set(year,dayOfYear,secondInDay*1000);
			return;			

		}	
	}
 }

  
     static public String toStringMonth2(int month){
        if (month<10)
            return "0"+month;
        else
            return ""+month;
    }
    
    /**
     * Generate a string of length 2 for day in month variable 
     * @param day - day in month
     * @return a string of length 2 for day in month variable 
     */
    static public String toStringDayInMonth2(int day){
        if (day<10){
            return "0"+day;
        }else{
            return ""+day;
        }
    }
 
    /**
     * Generate ISO8601 format time String
     * @return ISO8601 format time String
     */
    public String toStringISO8601(){
        
        String str=""+year+"-";
        str+=StringUtil.toString2(month)+"-";
        str+=StringUtil.toString2(day)+" ";
        str+=StringUtil.toString2(hour)+"-";
        str+=StringUtil.toString2(minute)+"-";
        str+=StringUtil.toString2(second)+"Z";
        return str;
    }
    
    /**
     * Set time using a ISO8601 string (YYYY-MM-DD HH-MM-SSZ)
     * @param strTime - ISO8601 string
     */
    public void setUsingISO8601String(String strTime){
        try{
            year=Short.parseShort(strTime.substring(0,4));
            month = Byte.parseByte(strTime.substring(5, 7));
            day = Byte.parseByte(strTime.substring(8, 10));
            hour = Byte.parseByte(strTime.substring(11, 13));
            minute = Byte.parseByte(strTime.substring(14, 16));
            second = Byte.parseByte(strTime.substring(17, 19));
        }catch (java.lang.NumberFormatException e) {
            year=0;month=0;day=0;hour=0;minute=0;second=0;
        }
        set(year, month, day, hour, minute, second);
    }

    /**
     * For debug purpose only
     * @param args 
     */
    static public void main(String[] args){
//x=2 y=36 spot=14 year=2002 mon=9 day=13 hour0 min=0 sec=4 lat=0.0097 lon=-173.4159 ftime=0.00115 ECT=11.56221 DiurnalCorr=-0.0012207031 LandType=0
        Time time=new Time();
        time.setBySecondsSince(6.62688044E8, (short)1978);
       float lst= GMT2LocalSolarTime(180,10,100f);
       int hour=(int)lst;
       int min=(int)((lst-hour)*60);
       int sec=(int)(((lst-hour)*60-min)*60);
       System.out.println("Hour="+hour+ " Min="+min+" Sec="+sec);          
    }
    
}


