/*@***h* AMSU-A_FCDR_STAR/vector.VectorFloatAverager.java
* NAME
*   vector.VectorFloatAverager.java 
* 
* PURPOSE
*   To support a float vector with variable length. 
* 
* DESCRIPTION
*   This class provides methods for calculating mean and standard deviation 
*   of a float vectors.
* 
* AUTHOR
*   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
* 
* CREATION DATE
*   05/20/2013
* 
* COPYRIGHT
*   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
*   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
*   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
*   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
*   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
*   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
*   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
*   SUPPORT TO USERS.
*    
*   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
*   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
*   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
*   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
*   DATA SET.
*    
*   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
*   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
*   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
*   support from NOAA's CDR Program.
*    
*   Citation Request: 
*       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
*       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
*       Vol. 116, D23113, doi:10.1029/2011JD016205
*       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
*       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
*       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
*       doi:10.1029/2005JD006798
*       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
*       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
* 
* REVISION HISTORY
*   05/20/2013 Initial Version prepared for NCDC
* 
*
*@*****/
 
 

package vector;


public class VectorFloatAverager extends VectorFloat{
     public int n; //actrual length of the float vector
     
    /**
     * Constructor
     * @param n - maximum length of float vector
     */     
     public VectorFloatAverager(int nMax){
         super(nMax);
         initAverager();
     }
     
     /**
      * Initialize float vector, setting its length to zero
      */
     public void initAverager(){
         n=0;
         super.init(0);
     }
     
     /**
      * Add a new value to the float vector
      * @param v - new value to be added
      */
     public void put(float v){
         data[n]=v;
         n++;
     }
     
     /**
      * Calculate mean of a float array by excluding elements whose distance from
      * the mean is larger than 3-sigma
      * @return 
      */
     public float caluclateMeanWith3Sigma(){
           float mean;
           mean=super.calMeanWith3Sigma(data,0,n-1,Float.NaN,Float.NaN,null);
           return mean;
     }

     /**
     * Calculate standard deviation of a float array using specified start and end index, 
     * without quality control.
      */
     public float calculateStddev(){
         float stddev=super.stddev(data, 0, n-1,Float.NaN, Float.NaN, Float.NaN);
         return stddev;
     }
}
