#@***h* AMSU-A_FCDR_STAR/gen_daily_tarfile.sh
# NAME
#   gen_daily_tarfile.sh
# 
# PURPOSE
#   To generate daily tar files for the AMSU-A radiance FCDR product
# 
# DESCRIPTION
#   This script packs AMSU-A level 1c FCDR orbit files into comparessed tar files. 
#   One compressed tar file is gnerated each day for each satellite.
#
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   06/19/2013
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   
# 
#@*****/
 
dirSrc0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1.nc4/
dirDst0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1.nc4.dailytarfile/


for satname in n15 n16 n17 n18 metopa aqua  
do

for year in 1999 1998 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013
do
  echo $satname $year
  subdir=$satname/$year/
  dirDst=$dirDst0$subdir
  dirSrc=$dirSrc0$subdir

  if [ -d $dirSrc ]; then   
      mkdir -p $dirDst
      echo $dirDst
      cd $dirSrc


       for month in 01 02 03 04 05 06 07 08 09 10 11 12 
       do
 
	     filter=NESDIS-STAR_*_D$year$month*.nc
             nfiles=`ls -1 $filter | wc -l`
             echo year=$year month=$month $nfiles
             if [ $nfiles -gt 0 ];then   #oribts exist in this month              
            
            for day in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
            do

                 #count # of oribit for a day
  		 filter=NESDIS-STAR_*_D$year$month$day*.nc
                 nfiles=`ls -1 $filter | wc -l`
                 echo year=$year month=$month day=$day nfiles=$nfiles
                
                  if [ $nfiles -gt 0 ];then
                 nfiles=0
                 for file in $filter
                 do
                     if [ $nfiles -eq 0 ]; then
                        len=${#file}
                        len1=$(( len-15 ))
                        creationDate=`date -dnow +%Y%m%d`
                        fileOut=${file:0:$len1}_C$creationDate.tar  
                        echo $file $len $len1 $fileOut 
                     fi
                     nfiles=$(( nfiles+1 ))
                 done
		 
		 #generate daily tar files
                 echo nfiles=$nfiles
		 if [ $nfiles -gt 0 ];then
		      #echo $fileOut
                    
                    tar -cvf $dirDst/$fileOut $filter
                    #gzip $dirDst/$fileOut $dirDst/$fileOut.gz
                 fi
                 fi
            done
  
         fi #month
         done #month
 
  fi



done  #year
done  #satname

