#@***h* AMSU-A_FCDR_STAR/gen_daily_tarfile.sh
# NAME
#   gen_manifest.sh
# 
# PURPOSE
#   To generate manifest file for each AMSU-A radiance FCDR daily tar file.
# 
# DESCRIPTION
#   This script generates manifest file for each AMSU-A radiance FCDR daily tar file.
#   The name of manifest file is as follow:
#	<daily_tar_file_name>.mnf
#   The content of manifest file contains:
#      1) the associated data file name followed by 
#      2) the corresponding MD5 checksum value and 
#      3) the file size. The three 
#  Text values are comma delimited on one line with no spaces.
#  Content format of values in a submission manifest file:
#      <data_file_name>,<data_file_md5_checksum>,<data_file_size>
#  Content example:
#    NESDIS-STAR_FCDR_AMSU-A_V02R00_N15_D20000101_c20000201.tar,da3e100dc9e7bebb810985e37875de38,13631488
#
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   07/13/2013
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   
# 
#@*****/
 

dirSrc0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1.nc4.dailytarfile/
dirDst0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1.nc4.dailytarfile.manifest/


for satname in n15 n16 n17 n18 metopa aqua  
do

for year in 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013
do
  echo $satname $year
  subdir=$satname/$year/
  dirDst=$dirDst0$subdir
  dirSrc=$dirSrc0$subdir

 if [ -d $dirSrc ]; then
      mkdir -p $dirDst
      echo $dirDst
      cd $dirSrc

      for file in NESDIS-STAR*.tar
      do
	   filesize=$(stat -c %s $file)
	   md50=$(md5sum  $file)
	   md5=($(echo $md50))

          pathDst=$dirDst$file.mnf
	   if [ -f $pathDst ]; then
		rm $pathDst
	   fi
	   #echo ${file}
	   #echo ${md5}
          #echo ${filesize}
	   echo ${file},$md5,${filesize} >>$pathDst
       
          echo ${file}.mnf  'generated!'

      done

  fi



done  #year
done  #satname

