#@***h* AMSU-A_FCDR_STAR/main.l1c.r2o.sh
# NAME
#   main.l1c.r2o.sh 
# 
# PURPOSE
#   To generate AMSU-A level 1c FCDR for all satellites
# 
# DESCRIPTION
#   This is the main script for generating AMSU-A level 1c FCDR for all satellites.
#   It first setups Java environment, the degree of concurrent processing,
#   and various configuration parameters for the Java main program, include directories 
#   for inputs and outputs, variables to be generated in the netCDF level 1c files, 
#   set of IMICA calibration coefficients to be used, and limb correction method.
# 
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   05/22/2013
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   05/22/2013 - added soure code header by Wenhui Wang
# 
#@*****/
 
 
#Setup Java envirement
#.  /net/orbit186l/home/wwang/bash_profile

#Configure degree of concurrent processing, nTheadMax=1 means no concurrent processing, level 1c files are generated 1 by 1.
nThreadsMax=1

#Root directory for code
rootDir=/data/data040/wwang/code/amsua/proc_level1c_netcdf_r2o/

#Root directory for storing FCDR files
rootDirData=/data/data040/wwang/data/amsua/l1c/

#Output level 1c file root directory
dirOut0=$rootDirData/r2o/tcdr.r2o.v1/
mkdir -p $dirOut0

#pathname for Java main program .jar that actually performs the AMSU-A level 1b to level 1c processing
#generateL1C=$rootDir/bin/MSUAMSUSSU.jar 
generateL1C=$rootDir/bin/AMSUALevel1CV1.jar 

#System configration parameters for the Java main class in the MSUAMSUSSU.jar file
antennacorrection=0             #no antenna pattern correction for the current version
limbcorrection=1                #generate limb effect adjusted temperatures using the Goldberg 2001 method
dirCoefficients=$rootDir/bin/   #directory for input ancillary files, such as IMICA calibration coefficients,
                                #land fraction, and limb correction coefficients
precip=1                        #perform precipitation screening
indexMuGroup=1                  #index of group of IMICA calibration coefficients used

#Configure which variables are generated in level 1c netcdf files, which are not generated
bGenerateRawCountProduct=false          #not generate raw counts fields in level 1c files
bGenerateLinearCalProduct=false         #not generate linear calibrated channel temperatures
bGenerateOPRProduct=TRUE                #generate NOAA operational (pre-launch) calibrated channel temperatures  
bGenerateSNOProduct=TRUE                #generate the IMICA recalibrated channel temperatures
bGenerateGeometryVariables=TRUE         #generate latitude, longititude, sensor view zenith angle, 
                                        #solar zenith angle, and local azimuth angle variables
bUseConvolvedCalibrationCounts=FALSE    #smooth calibration counts when generate the IMICA recalibrated temperatures


#Process level 1b data from each AMSU-A instruments to level 1c FCDR netCDF files
for satname in  n15 n16 n17 metopa aqua 
do
	#generate level 1c files for one instrument
	sh $rootDir/$satname.sh $generateL1C $dirOut0 $satname dirCoefficients=$dirCoefficients correctAntennaPattern=$antennacorrection limbCorrectionScheme=$limbcorrection checkPrecipitation=$precip indexMuGroup=$indexMuGroup bGenerateRawCountProduct=$bGenerateRawCountProduct bGenerateLinearCalProduct=$bGenerateLinearCalProduct bGenerateOPRProduct=$bGenerateOPRProduct bGenerateSNOProduct=$bGenerateSNOProduct bGenerateGeometryVariables=$bGenerateGeometryVariables nThreadMax=$nThreadsMax  bUseConvolvedCalibrationCounts=$bUseConvolvedCalibrationCounts

done

exit
 
#End of main script

