#@***h* AMSU-A_FCDR_STAR/n17.sh
# NAME
#   n17.sh 
# 
# PURPOSE
#   To generate AMSU-A level 1c radiance FCDR for NOAA-17
# 
# DESCRIPTION
#   This script generates AMSU-A radiance FCDR for NOAA-17, from 2002-2003
# 
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   05/17/2013
# 
#COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   05/17/2013 Initial Version prepared for NCDC
# 
# INPUTS
#   1. Pathname of the Java main program
#   2. satellite name
#   3. Java main program configuration parameters as defined in main.l1c.r2o.sh
# 
# OUTPUTS
#   AMSU-A radiance FCDR for NOAA-15 from 1998-2012
# 
#!/bin/bash
#@*****
 
 

generateL1C=$1 
dirOut0=$2
satname=$3


#directories for NOAA-17 AMSU-A level 1b data
dirIn_all=(/net/orbit001x/disk007/pub/amsu-a/noaa-17/2002 /net/orbit001x/disk002/pub/amsu-a/noaa-17/2003)


year_all=(2002 2003 )

echo $satname
for index in 0 1   
do
    dirIn=${dirIn_all[$index]}/
    echo $dirIn
    year=${year_all[$index]}

   
    echo $year
    echo $dirIn 

    dirOut=$dirOut0/$satname/$year
    mkdir -p $dirOut 

    java -jar $generateL1C satelliteName=$satname dirIn=$dirIn dirOut=$dirOut $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15}

done




