#@***h* AMSU-A_FCDR_STAR/n18.sh
# NAME
#   n18.sh
# 
# PURPOSE
#   To generate AMSU-A level 1c radiance FCDR for NOAA-18
# 
# DESCRIPTION
#   This script generates AMSU-A radiance FCDR for NOAA-18, from 2005-2012.
# 
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   05/17/2013
# 
#COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   05/17/2013 Initial Version prepared for NCDC
# 
# INPUTS
# 
# OUTPUTS
# 
#!/bin/bash
#@*****
 
 
#n18

generateL1C=$1 
dirOut0=$2
satname=$3

#directories for NOAA-18 AMSU-A level 1b data
dirIn_all=(/net/orbit001x/disk003/pub/amsu-a/noaa-18/2005 /net/orbit001x/disk009/pub/amsu-a/noaa-18/2006 /net/orbit001x/disk002/pub/amsu-a/noaa-18/2007 /net/orbit001x/disk008/pub/amsu-a/noaa-18/2008 /net/orbit001x/disk007/pub/amsu-a/noaa-18/2009 /net/orbit001x/disk002/pub/amsu-a/noaa-18/2010 /net/orbit001x/disk004/pub/amsu-a/noaa-18/2011  /net/orbit001x/disk007/pub/amsu-a/noaa-18/2012 /net/orbit001x/disk002/pub/amsu-a/noaa-18/2013)


year_all=(2005 2006 2007 2008 2009 2010 2011 2012 2013)

for index in 0 1 2 3 4 5 6 7 8
do
    dirIn=${dirIn_all[$index]}/
    year=${year_all[$index]}

   
    echo $year
    echo $dirIn 

    dirOut=$dirOut0/$satname/$year
    mkdir -p $dirOut
 
    java -jar $generateL1C satelliteName=$satname dirIn=$dirIn dirOut=$dirOut $4 $5 $6 $7 $8 $9 ${10} ${11} ${12} ${13} ${14} ${15}


done




