#@***h* AMSU-A_FCDR_STAR/nc3_to_nc4.sh
# NAME
#   nc3_to_nc4.sh 
# 
# PURPOSE
#   To convet AMSU-A level 1c FCDR files from netCDF-3 to netCDF-4 format
# 
# DESCRIPTION
#   This script converts AMSU-A level 1c FCDR files from netCDF-3 to netCDF-4 format
#   for all satellites. 
#   It calls the nccopy utitlity to convert netCDF-3 format FCDR files generated by the Java 
#   progrm to netCDF-4 files, with compression.
#
# AUTHOR
#   Wenhui Wang,  I. M. Systems Group@NOAA/NESDIS/STAR
# 
# CREATION DATE
#   06/03/2013
# 
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#    
#   Fair Use of NOAA's CDR Data Sets, Algorithms and Documentation: ALTHOUGH 
#   UNRESTRICTED, USERS OF THE SOFTWARE AND DATASETS SHOULD ACKNOWLEDGE 
#   AND CITE THE NOAA MSU/AMSU CDR TEAM IN THEIR PUBLICATIONS, PRESENTATIONS, 
#   AND/OR ANY DERIVED DATA PRODUCTS THAT WERE PRODUCED USING THE ORIGINAL 
#   DATA SET.
#    
#   Acknowledgement Request:  The AMSU-A FCDR used in this study was acquired 
#   from NOAA's National Climatic Data Center (http://www.ncdc.noaa.gov). This 
#   FCDR was originally developed by Cheng-Zhi Zou and Wenhui Wang through 
#   support from NOAA's CDR Program.
#    
#   Citation Request: 
#       Zou, Cheng-Zhi and Wenhui Wang (2011), Inter-satellite calibration of 
#       AMSU-A observations for weather and climate applications, J. Geophys. Res.,
#       Vol. 116, D23113, doi:10.1029/2011JD016205
#       Zou, C.-Z., M. Goldberg, Z. Cheng, N. Grody, J. Sullivan, C. Cao, and 
#       D. Tarpley (2006) Recalibration of microwave sounding unit for climate 
#       studies using simultaneous nadir overpasses. J. Geophys. Res., 111, D19114, 
#       doi:10.1029/2005JD006798
#       Goldberg, M. D., D. S. Crosby, and L. Zhou, (2001) The limb adjustment of 
#       AMSU-A observations: Methodology and validation. J. Appl. Meteor., 40, 70.83
# 
# REVISION HISTORY
#   06/03/2013 - added soure code header by Wenhui Wang
# 
#@*****/
 

dirSrc0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1/
dirDst0=/data/data040/wwang/data/amsua/l1c/r2o/tcdr.r2o.v1.nc4/

#pathname for nccopy, which convert netCDF-3 to netCDF-4
nccopy=/usr/local/NetCDF/netcdf-4.2.1.1/bin/nccopy

for satname in aqua #n15 n16 #n18 n17 metopa #n16 n17 n18 metopa aqua 
do
#for year in  2007 #2006 2007 2008 2009 2010 2011 2012 2013 
for year in  1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013
do
  subdir=$satname/$year/
  dirDst=$dirDst0$subdir
  dirSrc=$dirSrc0$subdir

  if [ -d $dirSrc ]; then
      mkdir -p $dirDst
      echo $dirDst
      cd $dirSrc

      for file in NESDIS-STAR*.nc
      do
          pathDst=$dirDst$file        
          $nccopy -k 4 -d 2 $file $pathDst
       
          echo $file  'converted!'
      done

  fi



done
done
